"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatasetValidationStatus = void 0;
/** The validation status of the dataset */
exports.DatasetValidationStatus = {
    Unknown: "unknown",
    Queued: "queued",
    Processing: "processing",
    Failed: "failed",
    Validated: "validated",
    Skipped: "skipped",
};
