"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoraTargetModules = void 0;
/**
 * The possible combinations of LoRA modules to target.
 *
 *  - LORA_TARGET_MODULES_UNSPECIFIED: Unspecified LoRA target modules.
 *  - LORA_TARGET_MODULES_QV: LoRA adapts the query and value matrices in transformer attention layers.
 *  - LORA_TARGET_MODULES_QKVO: LoRA adapts query, key, value, and output matrices in attention layers.
 *  - LORA_TARGET_MODULES_QKVO_FFN: LoRA adapts attention projection matrices and feed-forward networks (FFN).
 */
exports.LoraTargetModules = {
    LoraTargetModulesUnspecified: "LORA_TARGET_MODULES_UNSPECIFIED",
    LoraTargetModulesQv: "LORA_TARGET_MODULES_QV",
    LoraTargetModulesQkvo: "LORA_TARGET_MODULES_QKVO",
    LoraTargetModulesQkvoFfn: "LORA_TARGET_MODULES_QKVO_FFN",
};
