import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolContent } from "./ToolContent";
export declare const ToolMessageV2Content: core.serialization.Schema<serializers.ToolMessageV2Content.Raw, Cohere.ToolMessageV2Content>;
export declare namespace ToolMessageV2Content {
    type Raw = string | ToolContent.Raw[];
}
