import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatDocument } from "./ChatDocument";
import { ChatSearchResult } from "./ChatSearchResult";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatSearchResultsEvent: core.serialization.ObjectSchema<serializers.ChatSearchResultsEvent.Raw, Cohere.ChatSearchResultsEvent>;
export declare namespace ChatSearchResultsEvent {
    interface Raw extends ChatStreamEvent.Raw {
        search_results?: ChatSearchResult.Raw[] | null;
        documents?: ChatDocument.Raw[] | null;
    }
}
