import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatStreamRequestSafetyMode: core.serialization.Schema<serializers.ChatStreamRequestSafetyMode.Raw, Cohere.ChatStreamRequestSafetyMode>;
export declare namespace ChatStreamRequestSafetyMode {
    type Raw = "CONTEXTUAL" | "STRICT" | "NONE";
}
