import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
import { LoraTargetModules } from "./LoraTargetModules";
export declare const Hyperparameters: core.serialization.ObjectSchema<serializers.finetuning.Hyperparameters.Raw, Cohere.finetuning.Hyperparameters>;
export declare namespace Hyperparameters {
    interface Raw {
        early_stopping_patience?: number | null;
        early_stopping_threshold?: number | null;
        train_batch_size?: number | null;
        train_epochs?: number | null;
        learning_rate?: number | null;
        lora_alpha?: number | null;
        lora_rank?: number | null;
        lora_target_modules?: LoraTargetModules.Raw | null;
    }
}
