import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ConnectorOAuth: core.serialization.ObjectSchema<serializers.ConnectorOAuth.Raw, Cohere.ConnectorOAuth>;
export declare namespace ConnectorOAuth {
    interface Raw {
        client_id?: string | null;
        client_secret?: string | null;
        authorize_url: string;
        token_url: string;
        scope?: string | null;
    }
}
