import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
import { GenerateRequestReturnLikelihoods } from "../../types/GenerateRequestReturnLikelihoods";
import { GenerateRequestTruncate } from "../../types/GenerateRequestTruncate";
export declare const GenerateRequest: core.serialization.Schema<serializers.GenerateRequest.Raw, Cohere.GenerateRequest>;
export declare namespace GenerateRequest {
    interface Raw {
        prompt: string;
        model?: string | null;
        num_generations?: number | null;
        max_tokens?: number | null;
        truncate?: GenerateRequestTruncate.Raw | null;
        temperature?: number | null;
        seed?: number | null;
        preset?: string | null;
        end_sequences?: string[] | null;
        stop_sequences?: string[] | null;
        k?: number | null;
        p?: number | null;
        frequency_penalty?: number | null;
        presence_penalty?: number | null;
        return_likelihoods?: GenerateRequestReturnLikelihoods.Raw | null;
        raw_prompting?: boolean | null;
    }
}
