export interface ApiMetaTokens {
    /** The number of tokens used as input to the model. */
    inputTokens?: number;
    /** The number of tokens produced by the model. */
    outputTokens?: number;
}
