import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ClassifyResponseClassificationsItemLabelsValue: core.serialization.ObjectSchema<serializers.ClassifyResponseClassificationsItemLabelsValue.Raw, Cohere.ClassifyResponseClassificationsItemLabelsValue>;
export declare namespace ClassifyResponseClassificationsItemLabelsValue {
    interface Raw {
        confidence?: number | null;
    }
}
