import type * as Cohere from "../index";
export interface RerankResponse {
    id?: string;
    /** An ordered list of ranked documents */
    results: Cohere.RerankResponseResultsItem[];
    meta?: Cohere.ApiMeta;
}
