"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageUrlDetail = void 0;
/** Controls the level of detail in image processing. `"auto"` is the default and lets the system choose, `"low"` is faster but less detailed, and `"high"` preserves maximum detail. You can save tokens and speed up responses by using detail: `"low"`. */
exports.ImageUrlDetail = {
    Auto: "auto",
    Low: "low",
    High: "high",
};
