import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEvent } from "./ChatStreamEvent";
import { ToolCall } from "./ToolCall";
export declare const ChatToolCallsGenerationEvent: core.serialization.ObjectSchema<serializers.ChatToolCallsGenerationEvent.Raw, Cohere.ChatToolCallsGenerationEvent>;
export declare namespace ChatToolCallsGenerationEvent {
    interface Raw extends ChatStreamEvent.Raw {
        text?: string | null;
        tool_calls: ToolCall.Raw[];
    }
}
