/** The status of the embed job */
export declare const EmbedJobStatus: {
    readonly Processing: "processing";
    readonly Complete: "complete";
    readonly Cancelling: "cancelling";
    readonly Cancelled: "cancelled";
    readonly Failed: "failed";
};
export type EmbedJobStatus = (typeof EmbedJobStatus)[keyof typeof EmbedJobStatus];
