import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const CreateEmbedJobRequestTruncate: core.serialization.Schema<serializers.CreateEmbedJobRequestTruncate.Raw, Cohere.CreateEmbedJobRequestTruncate>;
export declare namespace CreateEmbedJobRequestTruncate {
    type Raw = "START" | "END";
}
