import type * as Cohere from "../index";
/**
 * Options for controlling citation generation.
 */
export interface CitationOptions {
    /**
     * Defaults to `"enabled"`.
     * Citations are enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`.
     */
    mode?: Cohere.CitationOptionsMode;
}
