/**
 * The possible stages of a batch life-cycle.
 *
 *  - BATCH_STATUS_UNSPECIFIED: Unspecified status.
 *  - BATCH_STATUS_QUEUED: The batch has been queued.
 *  - BATCH_STATUS_IN_PROGRESS: The batch is in-progress.
 *  - BATCH_STATUS_CANCELING: The batch is being canceled.
 *  - BATCH_STATUS_COMPLETED: The batch has been completed.
 *  - BATCH_STATUS_FAILED: The batch has failed.
 *  - BATCH_STATUS_CANCELED: The batch has been canceled.
 */
export declare const BatchStatus: {
    readonly BatchStatusUnspecified: "BATCH_STATUS_UNSPECIFIED";
    readonly BatchStatusQueued: "BATCH_STATUS_QUEUED";
    readonly BatchStatusInProgress: "BATCH_STATUS_IN_PROGRESS";
    readonly BatchStatusCanceling: "BATCH_STATUS_CANCELING";
    readonly BatchStatusCompleted: "BATCH_STATUS_COMPLETED";
    readonly BatchStatusFailed: "BATCH_STATUS_FAILED";
    readonly BatchStatusCanceled: "BATCH_STATUS_CANCELED";
};
export type BatchStatus = (typeof BatchStatus)[keyof typeof BatchStatus];
