import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatSearchQuery } from "./ChatSearchQuery";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatSearchQueriesGenerationEvent: core.serialization.ObjectSchema<serializers.ChatSearchQueriesGenerationEvent.Raw, Cohere.ChatSearchQueriesGenerationEvent>;
export declare namespace ChatSearchQueriesGenerationEvent {
    interface Raw extends ChatStreamEvent.Raw {
        search_queries: ChatSearchQuery.Raw[];
    }
}
