/** Reasoning is enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`. */
export declare const ThinkingType: {
    readonly Enabled: "enabled";
    readonly Disabled: "disabled";
};
export type ThinkingType = (typeof ThinkingType)[keyof typeof ThinkingType];
