import type * as Cohere from "../index";
/**
 * A streamed event which contains a delta of tool plan text.
 */
export interface ChatToolPlanDeltaEvent extends Cohere.ChatStreamEventType {
    delta?: Cohere.ChatToolPlanDeltaEventDelta;
}
