import type * as Cohere from "../index";
/**
 * A streamed event which signifies a citation has finished streaming.
 */
export interface CitationEndEvent extends Cohere.ChatStreamEventType {
    index?: number;
}
