import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ConnectorAuthStatus: core.serialization.Schema<serializers.ConnectorAuthStatus.Raw, Cohere.ConnectorAuthStatus>;
export declare namespace ConnectorAuthStatus {
    type Raw = "valid" | "expired";
}
