import type * as core from "../../core";
import * as errors from "../../errors/index";
export declare class GatewayTimeoutError extends errors.CohereError {
    constructor(body?: unknown, rawResponse?: core.RawResponse);
}
