import type * as Cohere from "../../../../index";
/**
 * @example
 *     {
 *         name: "name",
 *         settings: {
 *             baseModel: {
 *                 baseType: "BASE_TYPE_UNSPECIFIED"
 *             },
 *             datasetId: "dataset_id"
 *         }
 *     }
 */
export interface FinetuningUpdateFinetunedModelRequest {
    /** FinetunedModel name (e.g. `foobar`). */
    name: string;
    /** FinetunedModel settings such as dataset, hyperparameters... */
    settings: Cohere.finetuning.Settings;
    /** Current stage in the life-cycle of the fine-tuned model. */
    status?: Cohere.finetuning.Status;
}
