import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const FinishReason: core.serialization.Schema<serializers.FinishReason.Raw, Cohere.FinishReason>;
export declare namespace FinishReason {
    type Raw = "COMPLETE" | "STOP_SEQUENCE" | "ERROR" | "ERROR_TOXIC" | "ERROR_LIMIT" | "USER_CANCEL" | "MAX_TOKENS" | "TIMEOUT";
}
