import type * as Cohere from "../../../../../index";
/**
 * A change in status of a fine-tuned model.
 */
export interface Event {
    /** ID of the user who initiated the event. Empty if initiated by the system. */
    userId?: string;
    /** Status of the fine-tuned model. */
    status?: Cohere.finetuning.Status;
    /** Timestamp when the event happened. */
    createdAt?: Date;
}
