import type * as Cohere from "../index";
export interface ChatCitationGenerationEvent extends Cohere.ChatStreamEvent {
    /** Citations for the generated reply. */
    citations: Cohere.ChatCitation[];
}
