"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatCitationType = void 0;
/** The type of citation which indicates what part of the response the citation is for. */
exports.ChatCitationType = {
    TextContent: "TEXT_CONTENT",
    Plan: "PLAN",
};
