import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const DatasetsCreateResponse: core.serialization.ObjectSchema<serializers.DatasetsCreateResponse.Raw, Cohere.DatasetsCreateResponse>;
export declare namespace DatasetsCreateResponse {
    interface Raw {
        id?: string | null;
    }
}
