import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const DatasetType: core.serialization.Schema<serializers.DatasetType.Raw, Cohere.DatasetType>;
export declare namespace DatasetType {
    type Raw = "embed-input" | "embed-result" | "cluster-result" | "cluster-outliers" | "reranker-finetune-input" | "single-label-classification-finetune-input" | "chat-finetune-input" | "multi-label-classification-finetune-input" | "batch-chat-input" | "batch-openai-chat-input" | "batch-embed-v2-input" | "batch-chat-v2-input";
}
