/** Controls the level of detail in image processing. `"auto"` is the default and lets the system choose, `"low"` is faster but less detailed, and `"high"` preserves maximum detail. You can save tokens and speed up responses by using detail: `"low"`. */
export declare const ImageUrlDetail: {
    readonly Auto: "auto";
    readonly Low: "low";
    readonly High: "high";
};
export type ImageUrlDetail = (typeof ImageUrlDetail)[keyof typeof ImageUrlDetail];
