import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { Batch } from "./Batch";
export declare const GetBatchResponse: core.serialization.ObjectSchema<serializers.GetBatchResponse.Raw, Cohere.GetBatchResponse>;
export declare namespace GetBatchResponse {
    interface Raw {
        batch: Batch.Raw;
    }
}
