"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.CohereTimeoutError = void 0;
class CohereTimeoutError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, CohereTimeoutError.prototype);
    }
}
exports.CohereTimeoutError = CohereTimeoutError;
