import type * as Cohere from "../../../index";
/**
 * This resource represents a batch job.
 */
export interface Batch {
    /** read-only. Batch ID. */
    id?: string;
    /** Batch name (e.g. `foobar`). */
    name: string;
    /** read-only. User ID of the creator. */
    creatorId?: string;
    /** read-only. Organization ID. */
    orgId?: string;
    /** read-only. Current stage in the life-cycle of the batch. */
    status?: Cohere.BatchStatus;
    /** read-only. Creation timestamp. */
    createdAt?: Date;
    /** read-only. Latest update timestamp. */
    updatedAt?: Date;
    /** ID of the dataset the batch reads inputs from. */
    inputDatasetId: string;
    outputDatasetId?: string;
    /** read-only. The total number of input tokens in the batch. */
    inputTokens?: string;
    /** read-only. The total number of output tokens in the batch. */
    outputTokens?: string;
    /** The name of the model the batch uses. */
    model: string;
    /** read-only. The total number of records in the batch. */
    numRecords?: number;
    /** read-only. The current number of successful records in the batch. */
    numSuccessfulRecords?: number;
    /** read-only. The current number of failed records in the batch. */
    numFailedRecords?: number;
    /** read-only. More details about the reason for the status of a batch job. */
    statusReason?: string;
}
