import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatTextResponseFormatV2: core.serialization.ObjectSchema<serializers.ChatTextResponseFormatV2.Raw, Cohere.ChatTextResponseFormatV2>;
export declare namespace ChatTextResponseFormatV2 {
    type Raw = {};
}
