import { V2 } from "./api/resources/v2/client/Client";
import { CohereClient } from "./Client";
export declare class CohereClientV2 implements Omit<CohereClient, keyof V2 | "v2">, Pick<V2, keyof V2> {
    private _options;
    constructor(_options: CohereClient.Options);
    private client;
    private clientV2;
    chat: typeof V2.prototype.chat;
    chatStream: typeof V2.prototype.chatStream;
    embed: typeof V2.prototype.embed;
    rerank: typeof V2.prototype.rerank;
    generateStream: typeof CohereClient.prototype.generateStream;
    generate: typeof CohereClient.prototype.generate;
    classify: typeof CohereClient.prototype.classify;
    summarize: typeof CohereClient.prototype.summarize;
    tokenize: typeof CohereClient.prototype.tokenize;
    detokenize: typeof CohereClient.prototype.detokenize;
    checkApiKey: typeof CohereClient.prototype.checkApiKey;
    embedJobs: typeof CohereClient.prototype.embedJobs;
    datasets: typeof CohereClient.prototype.datasets;
    connectors: typeof CohereClient.prototype.connectors;
    models: typeof CohereClient.prototype.models;
    finetuning: typeof CohereClient.prototype.finetuning;
    batches: typeof CohereClient.prototype.batches;
}
