import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ClassifyResponseClassificationsItemClassificationType } from "./ClassifyResponseClassificationsItemClassificationType";
import { ClassifyResponseClassificationsItemLabelsValue } from "./ClassifyResponseClassificationsItemLabelsValue";
export declare const ClassifyResponseClassificationsItem: core.serialization.ObjectSchema<serializers.ClassifyResponseClassificationsItem.Raw, Cohere.ClassifyResponseClassificationsItem>;
export declare namespace ClassifyResponseClassificationsItem {
    interface Raw {
        id: string;
        input?: string | null;
        prediction?: string | null;
        predictions: string[];
        confidence?: number | null;
        confidences: number[];
        labels: Record<string, ClassifyResponseClassificationsItemLabelsValue.Raw>;
        classification_type: ClassifyResponseClassificationsItemClassificationType.Raw;
    }
}
