"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatasetType = void 0;
/** The type of the dataset */
exports.DatasetType = {
    EmbedInput: "embed-input",
    EmbedResult: "embed-result",
    ClusterResult: "cluster-result",
    ClusterOutliers: "cluster-outliers",
    RerankerFinetuneInput: "reranker-finetune-input",
    SingleLabelClassificationFinetuneInput: "single-label-classification-finetune-input",
    ChatFinetuneInput: "chat-finetune-input",
    MultiLabelClassificationFinetuneInput: "multi-label-classification-finetune-input",
    BatchChatInput: "batch-chat-input",
    BatchOpenaiChatInput: "batch-openai-chat-input",
    BatchEmbedV2Input: "batch-embed-v2-input",
    BatchChatV2Input: "batch-chat-v2-input",
};
