/** The type of the dataset */
export declare const DatasetType: {
    readonly EmbedInput: "embed-input";
    readonly EmbedResult: "embed-result";
    readonly ClusterResult: "cluster-result";
    readonly ClusterOutliers: "cluster-outliers";
    readonly RerankerFinetuneInput: "reranker-finetune-input";
    readonly SingleLabelClassificationFinetuneInput: "single-label-classification-finetune-input";
    readonly ChatFinetuneInput: "chat-finetune-input";
    readonly MultiLabelClassificationFinetuneInput: "multi-label-classification-finetune-input";
    readonly BatchChatInput: "batch-chat-input";
    readonly BatchOpenaiChatInput: "batch-openai-chat-input";
    readonly BatchEmbedV2Input: "batch-embed-v2-input";
    readonly BatchChatV2Input: "batch-chat-v2-input";
};
export type DatasetType = (typeof DatasetType)[keyof typeof DatasetType];
