import type * as Cohere from "../index";
/**
 * A streamed delta event which signifies that the content block has ended.
 */
export interface ChatContentEndEvent extends Cohere.ChatStreamEventType {
    index?: number;
}
