"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbedJobTruncate = void 0;
/** The truncation option used */
exports.EmbedJobTruncate = {
    Start: "START",
    End: "END",
};
