import type * as Cohere from "../index";
export type EmbedContent = Cohere.EmbedContent.ImageUrl | Cohere.EmbedContent.Text;
export declare namespace EmbedContent {
    interface ImageUrl extends Cohere.EmbedImage {
        type: "image_url";
    }
    interface Text extends Cohere.EmbedText {
        type: "text";
    }
}
