import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const CitationType: core.serialization.Schema<serializers.CitationType.Raw, Cohere.CitationType>;
export declare namespace CitationType {
    type Raw = "TEXT_CONTENT" | "THINKING_CONTENT" | "PLAN";
}
