import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEventType } from "./ChatStreamEventType";
import { ChatToolPlanDeltaEventDelta } from "./ChatToolPlanDeltaEventDelta";
export declare const ChatToolPlanDeltaEvent: core.serialization.ObjectSchema<serializers.ChatToolPlanDeltaEvent.Raw, Cohere.ChatToolPlanDeltaEvent>;
export declare namespace ChatToolPlanDeltaEvent {
    interface Raw extends ChatStreamEventType.Raw {
        delta?: ChatToolPlanDeltaEventDelta.Raw | null;
    }
}
