/**
 * @example
 *     {
 *         afterTokenRedirect: "after_token_redirect"
 *     }
 */
export interface ConnectorsOAuthAuthorizeRequest {
    /** The URL to redirect to after the connector has been authorized. */
    afterTokenRedirect?: string;
}
