import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { Dataset } from "../../../types/Dataset";
export declare const DatasetsGetResponse: core.serialization.ObjectSchema<serializers.DatasetsGetResponse.Raw, Cohere.DatasetsGetResponse>;
export declare namespace DatasetsGetResponse {
    interface Raw {
        dataset: Dataset.Raw;
    }
}
