/**
 * Contains the tool calls generated by the model. Use it to invoke your tools.
 */
export interface ToolCall {
    /** Name of the tool to call. */
    name: string;
    /** The name and value of the parameters to use when invoking a tool. */
    parameters: Record<string, unknown>;
}
