/**
 * Thinking content of the message. This will be present when `thinking` is enabled, and will contain the models internal reasoning.
 */
export interface ChatThinkingContent {
    thinking: string;
}
