import type * as Cohere from "../index";
/**
 * Response in content type stream when `stream` is `true` in the request parameters. Generation tokens are streamed with the GenerationStream response. The final response is of type GenerationFinalResponse.
 */
export type GenerateStreamedResponse = Cohere.GenerateStreamedResponse.TextGeneration | Cohere.GenerateStreamedResponse.StreamEnd | Cohere.GenerateStreamedResponse.StreamError;
export declare namespace GenerateStreamedResponse {
    interface TextGeneration extends Cohere.GenerateStreamText {
        eventType: "text-generation";
    }
    interface StreamEnd extends Cohere.GenerateStreamEnd {
        eventType: "stream-end";
    }
    interface StreamError extends Cohere.GenerateStreamError {
        eventType: "stream-error";
    }
}
