import type * as Cohere from "../index";
export interface ChatToolCallsGenerationEvent extends Cohere.ChatStreamEvent {
    /** The text generated related to the tool calls generated */
    text?: string;
    toolCalls: Cohere.ToolCall[];
}
