import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatToolPlanDeltaEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatToolPlanDeltaEventDeltaMessage.Raw, Cohere.ChatToolPlanDeltaEventDeltaMessage>;
export declare namespace ChatToolPlanDeltaEventDeltaMessage {
    interface Raw {
        tool_plan?: string | null;
    }
}
