import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { ClassifyResponseClassificationsItem } from "./ClassifyResponseClassificationsItem";
export declare const ClassifyResponse: core.serialization.ObjectSchema<serializers.ClassifyResponse.Raw, Cohere.ClassifyResponse>;
export declare namespace ClassifyResponse {
    interface Raw {
        id: string;
        classifications: ClassifyResponseClassificationsItem.Raw[];
        meta?: ApiMeta.Raw | null;
    }
}
