import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentDeltaEventDeltaMessage } from "./ChatContentDeltaEventDeltaMessage";
export declare const ChatContentDeltaEventDelta: core.serialization.ObjectSchema<serializers.ChatContentDeltaEventDelta.Raw, Cohere.ChatContentDeltaEventDelta>;
export declare namespace ChatContentDeltaEventDelta {
    interface Raw {
        message?: ChatContentDeltaEventDeltaMessage.Raw | null;
    }
}
