import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const GenerateRequestReturnLikelihoods: core.serialization.Schema<serializers.GenerateRequestReturnLikelihoods.Raw, Cohere.GenerateRequestReturnLikelihoods>;
export declare namespace GenerateRequestReturnLikelihoods {
    type Raw = "GENERATION" | "ALL" | "NONE";
}
