import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ImageUrl } from "./ImageUrl";
export declare const ImageContent: core.serialization.ObjectSchema<serializers.ImageContent.Raw, Cohere.ImageContent>;
export declare namespace ImageContent {
    interface Raw {
        image_url: ImageUrl.Raw;
    }
}
