import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const SummarizeRequestLength: core.serialization.Schema<serializers.SummarizeRequestLength.Raw, Cohere.SummarizeRequestLength>;
export declare namespace SummarizeRequestLength {
    type Raw = "short" | "medium" | "long";
}
