import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentDeltaEventDelta } from "./ChatContentDeltaEventDelta";
import { ChatStreamEventType } from "./ChatStreamEventType";
import { LogprobItem } from "./LogprobItem";
export declare const ChatContentDeltaEvent: core.serialization.ObjectSchema<serializers.ChatContentDeltaEvent.Raw, Cohere.ChatContentDeltaEvent>;
export declare namespace ChatContentDeltaEvent {
    interface Raw extends ChatStreamEventType.Raw {
        index?: number | null;
        delta?: ChatContentDeltaEventDelta.Raw | null;
        logprobs?: LogprobItem.Raw | null;
    }
}
