import type * as Cohere from "../../../index";
export interface V2ChatResponse {
    /** Unique identifier for the generated reply. Useful for submitting feedback. */
    id: string;
    finishReason: Cohere.ChatFinishReason;
    message: Cohere.AssistantMessageResponse;
    usage?: Cohere.Usage;
    logprobs?: Cohere.LogprobItem[];
}
