import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const V2EmbedRequestTruncate: core.serialization.Schema<serializers.V2EmbedRequestTruncate.Raw, Cohere.V2EmbedRequestTruncate>;
export declare namespace V2EmbedRequestTruncate {
    type Raw = "NONE" | "START" | "END";
}
