import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatToolCallDeltaEventDeltaMessageToolCallsFunction } from "./ChatToolCallDeltaEventDeltaMessageToolCallsFunction";
export declare const ChatToolCallDeltaEventDeltaMessageToolCalls: core.serialization.ObjectSchema<serializers.ChatToolCallDeltaEventDeltaMessageToolCalls.Raw, Cohere.ChatToolCallDeltaEventDeltaMessageToolCalls>;
export declare namespace ChatToolCallDeltaEventDeltaMessageToolCalls {
    interface Raw {
        function?: ChatToolCallDeltaEventDeltaMessageToolCallsFunction.Raw | null;
    }
}
