import type * as Cohere from "../index";
/**
 * A streamed event which signifies a citation has been created.
 */
export interface CitationStartEvent extends Cohere.ChatStreamEventType {
    index?: number;
    delta?: Cohere.CitationStartEventDelta;
}
