/**
 * Used to select the [safety instruction](https://docs.cohere.com/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
 * When `NONE` is specified, the safety instruction will be omitted.
 *
 * Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
 *
 * **Note**: This parameter is only compatible newer Cohere models, starting with [Command R 08-2024](https://docs.cohere.com/docs/command-r#august-2024-release) and [Command R+ 08-2024](https://docs.cohere.com/docs/command-r-plus#august-2024-release).
 *
 * **Note**: `command-r7b-12-2024` and newer models only support `"CONTEXTUAL"` and `"STRICT"` modes.
 *
 * Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
 */
export declare const ChatRequestSafetyMode: {
    readonly Contextual: "CONTEXTUAL";
    readonly Strict: "STRICT";
    readonly None: "NONE";
};
export type ChatRequestSafetyMode = (typeof ChatRequestSafetyMode)[keyof typeof ChatRequestSafetyMode];
