/** The token_type specifies the way the token is passed in the Authorization header. Valid values are "bearer", "basic", and "noscheme". */
export declare const AuthTokenType: {
    readonly Bearer: "bearer";
    readonly Basic: "basic";
    readonly Noscheme: "noscheme";
};
export type AuthTokenType = (typeof AuthTokenType)[keyof typeof AuthTokenType];
