import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { UsageBilledUnits } from "./UsageBilledUnits";
import { UsageTokens } from "./UsageTokens";
export declare const Usage: core.serialization.ObjectSchema<serializers.Usage.Raw, Cohere.Usage>;
export declare namespace Usage {
    interface Raw {
        billed_units?: UsageBilledUnits.Raw | null;
        tokens?: UsageTokens.Raw | null;
        cached_tokens?: number | null;
    }
}
