/**
 * An object with different embedding types. The length of each embedding type array will be the same as the length of the original `texts` array.
 */
export interface EmbedByTypeResponseEmbeddings {
    /** An array of float embeddings. */
    float?: number[][];
    /** An array of signed int8 embeddings. Each value is between -128 and 127. */
    int8?: number[][];
    /** An array of unsigned int8 embeddings. Each value is between 0 and 255. */
    uint8?: number[][];
    /** An array of packed signed binary embeddings. The length of each binary embedding is 1/8 the length of the float embeddings of the provided model. Each value is between -128 and 127. */
    binary?: number[][];
    /** An array of packed unsigned binary embeddings. The length of each binary embedding is 1/8 the length of the float embeddings of the provided model. Each value is between 0 and 255. */
    ubinary?: number[][];
    /** An array of base64 embeddings. Each string is the result of appending the float embedding bytes together and base64 encoding that. */
    base64?: string[];
}
