/**
 * One of `GENERATION|NONE` to specify how and if the token likelihoods are returned with the response. Defaults to `NONE`.
 *
 * If `GENERATION` is selected, the token likelihoods will only be provided for generated text.
 *
 * WARNING: `ALL` is deprecated, and will be removed in a future release.
 */
export declare const GenerateStreamRequestReturnLikelihoods: {
    readonly Generation: "GENERATION";
    readonly All: "ALL";
    readonly None: "NONE";
};
export type GenerateStreamRequestReturnLikelihoods = (typeof GenerateStreamRequestReturnLikelihoods)[keyof typeof GenerateStreamRequestReturnLikelihoods];
