import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { SystemMessageV2Content } from "./SystemMessageV2Content";
export declare const SystemMessageV2: core.serialization.ObjectSchema<serializers.SystemMessageV2.Raw, Cohere.SystemMessageV2>;
export declare namespace SystemMessageV2 {
    interface Raw {
        content: SystemMessageV2Content.Raw;
    }
}
