import type * as Cohere from "../../../index";
/**
 * Response to a request to list batches.
 */
export interface ListBatchesResponse {
    /** The batches that belong to the authenticated user. */
    batches?: Cohere.Batch[];
    /**
     * A token, which can be sent as `page_token` to retrieve the next page.
     * If this field is omitted, there are no subsequent pages.
     */
    nextPageToken?: string;
}
