/**
 * The possible combinations of LoRA modules to target.
 *
 *  - LORA_TARGET_MODULES_UNSPECIFIED: Unspecified LoRA target modules.
 *  - LORA_TARGET_MODULES_QV: LoRA adapts the query and value matrices in transformer attention layers.
 *  - LORA_TARGET_MODULES_QKVO: LoRA adapts query, key, value, and output matrices in attention layers.
 *  - LORA_TARGET_MODULES_QKVO_FFN: LoRA adapts attention projection matrices and feed-forward networks (FFN).
 */
export declare const LoraTargetModules: {
    readonly LoraTargetModulesUnspecified: "LORA_TARGET_MODULES_UNSPECIFIED";
    readonly LoraTargetModulesQv: "LORA_TARGET_MODULES_QV";
    readonly LoraTargetModulesQkvo: "LORA_TARGET_MODULES_QKVO";
    readonly LoraTargetModulesQkvoFfn: "LORA_TARGET_MODULES_QKVO_FFN";
};
export type LoraTargetModules = (typeof LoraTargetModules)[keyof typeof LoraTargetModules];
