"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.CohereEnvironment = void 0;
exports.CohereEnvironment = {
    Production: "https://api.cohere.com",
};
