import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { ApiMeta } from "../../../types/ApiMeta";
import { V2RerankResponseResultsItem } from "./V2RerankResponseResultsItem";
export declare const V2RerankResponse: core.serialization.ObjectSchema<serializers.V2RerankResponse.Raw, Cohere.V2RerankResponse>;
export declare namespace V2RerankResponse {
    interface Raw {
        id?: string | null;
        results: V2RerankResponseResultsItem.Raw[];
        meta?: ApiMeta.Raw | null;
    }
}
