import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolMessageV2Content } from "./ToolMessageV2Content";
export declare const ToolMessageV2: core.serialization.ObjectSchema<serializers.ToolMessageV2.Raw, Cohere.ToolMessageV2>;
export declare namespace ToolMessageV2 {
    interface Raw {
        tool_call_id: string;
        content: ToolMessageV2Content.Raw;
    }
}
