"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Strategy = void 0;
/**
 * The possible strategy used to serve a fine-tuned models.
 *
 *  - STRATEGY_UNSPECIFIED: Unspecified strategy.
 *  - STRATEGY_VANILLA: Deprecated: Serve the fine-tuned model on a dedicated GPU.
 *  - STRATEGY_TFEW: Deprecated: Serve the fine-tuned model on a shared GPU.
 */
exports.Strategy = {
    StrategyUnspecified: "STRATEGY_UNSPECIFIED",
    StrategyVanilla: "STRATEGY_VANILLA",
    StrategyTfew: "STRATEGY_TFEW",
};
