import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const WandbConfig: core.serialization.ObjectSchema<serializers.finetuning.WandbConfig.Raw, Cohere.finetuning.WandbConfig>;
export declare namespace WandbConfig {
    interface Raw {
        project: string;
        api_key: string;
        entity?: string | null;
    }
}
