import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { CitationType } from "./CitationType";
import { Source } from "./Source";
export declare const Citation: core.serialization.ObjectSchema<serializers.Citation.Raw, Cohere.Citation>;
export declare namespace Citation {
    interface Raw {
        start?: number | null;
        end?: number | null;
        text?: string | null;
        sources?: Source.Raw[] | null;
        content_index?: number | null;
        type?: CitationType.Raw | null;
    }
}
