/** The truncation option used */
export declare const EmbedJobTruncate: {
    readonly Start: "START";
    readonly End: "END";
};
export type EmbedJobTruncate = (typeof EmbedJobTruncate)[keyof typeof EmbedJobTruncate];
