import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatMessageStartEventDeltaMessage } from "./ChatMessageStartEventDeltaMessage";
export declare const ChatMessageStartEventDelta: core.serialization.ObjectSchema<serializers.ChatMessageStartEventDelta.Raw, Cohere.ChatMessageStartEventDelta>;
export declare namespace ChatMessageStartEventDelta {
    interface Raw {
        message?: ChatMessageStartEventDeltaMessage.Raw | null;
    }
}
