import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const BatchStatus: core.serialization.Schema<serializers.BatchStatus.Raw, Cohere.BatchStatus>;
export declare namespace BatchStatus {
    type Raw = "BATCH_STATUS_UNSPECIFIED" | "BATCH_STATUS_QUEUED" | "BATCH_STATUS_IN_PROGRESS" | "BATCH_STATUS_CANCELING" | "BATCH_STATUS_COMPLETED" | "BATCH_STATUS_FAILED" | "BATCH_STATUS_CANCELED";
}
