import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolCall } from "./ToolCall";
export declare const ToolResult: core.serialization.ObjectSchema<serializers.ToolResult.Raw, Cohere.ToolResult>;
export declare namespace ToolResult {
    interface Raw {
        call: ToolCall.Raw;
        outputs: Record<string, unknown>[];
    }
}
