"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseType = void 0;
/**
 * The possible types of fine-tuned models.
 *
 *  - BASE_TYPE_UNSPECIFIED: Unspecified model.
 *  - BASE_TYPE_GENERATIVE: Deprecated: Generative model.
 *  - BASE_TYPE_CLASSIFICATION: Classification model.
 *  - BASE_TYPE_RERANK: Rerank model.
 *  - BASE_TYPE_CHAT: Chat model.
 */
exports.BaseType = {
    BaseTypeUnspecified: "BASE_TYPE_UNSPECIFIED",
    BaseTypeGenerative: "BASE_TYPE_GENERATIVE",
    BaseTypeClassification: "BASE_TYPE_CLASSIFICATION",
    BaseTypeRerank: "BASE_TYPE_RERANK",
    BaseTypeChat: "BASE_TYPE_CHAT",
};
