import type * as Cohere from "../index";
export type AssistantMessageResponseContentItem = Cohere.AssistantMessageResponseContentItem.Text | Cohere.AssistantMessageResponseContentItem.Thinking;
export declare namespace AssistantMessageResponseContentItem {
    interface Text extends Cohere.ChatTextContent {
        type: "text";
    }
    interface Thinking extends Cohere.ChatThinkingContent {
        type: "thinking";
    }
}
