import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatDebugEvent: core.serialization.ObjectSchema<serializers.ChatDebugEvent.Raw, Cohere.ChatDebugEvent>;
export declare namespace ChatDebugEvent {
    interface Raw extends ChatStreamEvent.Raw {
        prompt?: string | null;
    }
}
