export interface ApiMetaBilledUnits {
    /** The number of billed images. */
    images?: number;
    /** The number of billed input tokens. */
    inputTokens?: number;
    /** The number of billed output tokens. */
    outputTokens?: number;
    /** The number of billed search units. */
    searchUnits?: number;
    /** The number of billed classifications units. */
    classifications?: number;
}
