import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
import { Settings } from "./Settings";
import { Status } from "./Status";
export declare const FinetunedModel: core.serialization.ObjectSchema<serializers.finetuning.FinetunedModel.Raw, Cohere.finetuning.FinetunedModel>;
export declare namespace FinetunedModel {
    interface Raw {
        id?: string | null;
        name: string;
        creator_id?: string | null;
        organization_id?: string | null;
        settings: Settings.Raw;
        status?: Status.Raw | null;
        created_at?: string | null;
        updated_at?: string | null;
        completed_at?: string | null;
        last_used?: string | null;
    }
}
