import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const V2ChatStreamRequestSafetyMode: core.serialization.Schema<serializers.V2ChatStreamRequestSafetyMode.Raw, Cohere.V2ChatStreamRequestSafetyMode>;
export declare namespace V2ChatStreamRequestSafetyMode {
    type Raw = "CONTEXTUAL" | "STRICT" | "OFF";
}
