import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { SingleGeneration } from "./SingleGeneration";
export declare const Generation: core.serialization.ObjectSchema<serializers.Generation.Raw, Cohere.Generation>;
export declare namespace Generation {
    interface Raw {
        id: string;
        prompt?: string | null;
        generations: SingleGeneration.Raw[];
        meta?: ApiMeta.Raw | null;
    }
}
