import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const AuthTokenType: core.serialization.Schema<serializers.AuthTokenType.Raw, Cohere.AuthTokenType>;
export declare namespace AuthTokenType {
    type Raw = "bearer" | "basic" | "noscheme";
}
