/**
 * - `COMPLETE` - the model sent back a finished reply
 * - `ERROR_LIMIT` - the reply was cut off because the model reached the maximum number of tokens for its context length
 * - `MAX_TOKENS` - the reply was cut off because the model reached the maximum number of tokens specified by the max_tokens parameter
 * - `ERROR` - something went wrong when generating the reply
 * - `ERROR_TOXIC` - the model generated a reply that was deemed toxic
 */
export declare const ChatStreamEndEventFinishReason: {
    readonly Complete: "COMPLETE";
    readonly ErrorLimit: "ERROR_LIMIT";
    readonly MaxTokens: "MAX_TOKENS";
    readonly Error: "ERROR";
    readonly ErrorToxic: "ERROR_TOXIC";
};
export type ChatStreamEndEventFinishReason = (typeof ChatStreamEndEventFinishReason)[keyof typeof ChatStreamEndEventFinishReason];
