import { CohereClient } from "./Client";
export declare class CustomClient extends CohereClient {
    protected readonly _options: CohereClient.Options;
    constructor(_options?: CohereClient.Options);
}
