import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ThinkingType } from "./ThinkingType";
export declare const Thinking: core.serialization.ObjectSchema<serializers.Thinking.Raw, Cohere.Thinking>;
export declare namespace Thinking {
    interface Raw {
        type: ThinkingType.Raw;
        token_budget?: number | null;
    }
}
