import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { Citation } from "./Citation";
export declare const CitationStartEventDeltaMessage: core.serialization.ObjectSchema<serializers.CitationStartEventDeltaMessage.Raw, Cohere.CitationStartEventDeltaMessage>;
export declare namespace CitationStartEventDeltaMessage {
    interface Raw {
        citations?: Citation.Raw | null;
    }
}
