import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ClassifyExample: core.serialization.ObjectSchema<serializers.ClassifyExample.Raw, Cohere.ClassifyExample>;
export declare namespace ClassifyExample {
    interface Raw {
        text?: string | null;
        label?: string | null;
    }
}
