export interface LabelMetric {
    /** Total number of examples for this label */
    totalExamples?: number;
    /** value of the label */
    label?: string;
    /** samples for this label */
    samples?: string[];
}
