import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { CitationOptionsMode } from "./CitationOptionsMode";
export declare const CitationOptions: core.serialization.ObjectSchema<serializers.CitationOptions.Raw, Cohere.CitationOptions>;
export declare namespace CitationOptions {
    interface Raw {
        mode?: CitationOptionsMode.Raw | null;
    }
}
