import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatCitationType } from "./ChatCitationType";
export declare const ChatCitation: core.serialization.ObjectSchema<serializers.ChatCitation.Raw, Cohere.ChatCitation>;
export declare namespace ChatCitation {
    interface Raw {
        start: number;
        end: number;
        text: string;
        document_ids: string[];
        type?: ChatCitationType.Raw | null;
    }
}
