import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
export declare const DetokenizeResponse: core.serialization.ObjectSchema<serializers.DetokenizeResponse.Raw, Cohere.DetokenizeResponse>;
export declare namespace DetokenizeResponse {
    interface Raw {
        text: string;
        meta?: ApiMeta.Raw | null;
    }
}
