import type * as Cohere from "../index";
export interface CreateConnectorServiceAuth {
    type: Cohere.AuthTokenType;
    /** The token that will be used in the HTTP Authorization header when making requests to the connector. This field is encrypted at rest and never returned in a response. */
    token: string;
}
