import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { EmbedByTypeResponseEmbeddings } from "./EmbedByTypeResponseEmbeddings";
import { Image } from "./Image";
export declare const EmbedByTypeResponse: core.serialization.ObjectSchema<serializers.EmbedByTypeResponse.Raw, Cohere.EmbedByTypeResponse>;
export declare namespace EmbedByTypeResponse {
    interface Raw {
        id: string;
        embeddings: EmbedByTypeResponseEmbeddings.Raw;
        texts?: string[] | null;
        images?: Image.Raw[] | null;
        meta?: ApiMeta.Raw | null;
    }
}
