import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ToolCallDelta: core.serialization.ObjectSchema<serializers.ToolCallDelta.Raw, Cohere.ToolCallDelta>;
export declare namespace ToolCallDelta {
    interface Raw {
        name?: string | null;
        index?: number | null;
        parameters?: string | null;
        text?: string | null;
    }
}
