export declare const FinishReason: {
    readonly Complete: "COMPLETE";
    readonly StopSequence: "STOP_SEQUENCE";
    readonly Error: "ERROR";
    readonly ErrorToxic: "ERROR_TOXIC";
    readonly ErrorLimit: "ERROR_LIMIT";
    readonly UserCancel: "USER_CANCEL";
    readonly MaxTokens: "MAX_TOKENS";
    readonly Timeout: "TIMEOUT";
};
export type FinishReason = (typeof FinishReason)[keyof typeof FinishReason];
