import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEvent } from "./ChatStreamEvent";
import { ToolCallDelta } from "./ToolCallDelta";
export declare const ChatToolCallsChunkEvent: core.serialization.ObjectSchema<serializers.ChatToolCallsChunkEvent.Raw, Cohere.ChatToolCallsChunkEvent>;
export declare namespace ChatToolCallsChunkEvent {
    interface Raw extends ChatStreamEvent.Raw {
        tool_call_delta: ToolCallDelta.Raw;
        text?: string | null;
    }
}
