import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMetaApiVersion } from "./ApiMetaApiVersion";
import { ApiMetaBilledUnits } from "./ApiMetaBilledUnits";
import { ApiMetaTokens } from "./ApiMetaTokens";
export declare const ApiMeta: core.serialization.ObjectSchema<serializers.ApiMeta.Raw, Cohere.ApiMeta>;
export declare namespace ApiMeta {
    interface Raw {
        api_version?: ApiMetaApiVersion.Raw | null;
        billed_units?: ApiMetaBilledUnits.Raw | null;
        tokens?: ApiMetaTokens.Raw | null;
        cached_tokens?: number | null;
        warnings?: string[] | null;
    }
}
