import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatDocumentSource: core.serialization.ObjectSchema<serializers.ChatDocumentSource.Raw, Cohere.ChatDocumentSource>;
export declare namespace ChatDocumentSource {
    interface Raw {
        id?: string | null;
        document?: Record<string, unknown> | null;
    }
}
