import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedJobTruncate: core.serialization.Schema<serializers.EmbedJobTruncate.Raw, Cohere.EmbedJobTruncate>;
export declare namespace EmbedJobTruncate {
    type Raw = "START" | "END";
}
