import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatStreamEndEventFinishReason: core.serialization.Schema<serializers.ChatStreamEndEventFinishReason.Raw, Cohere.ChatStreamEndEventFinishReason>;
export declare namespace ChatStreamEndEventFinishReason {
    type Raw = "COMPLETE" | "ERROR_LIMIT" | "MAX_TOKENS" | "ERROR" | "ERROR_TOXIC";
}
