import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { FinishReason } from "./FinishReason";
import { GenerateStreamEndResponse } from "./GenerateStreamEndResponse";
import { GenerateStreamEvent } from "./GenerateStreamEvent";
export declare const GenerateStreamEnd: core.serialization.ObjectSchema<serializers.GenerateStreamEnd.Raw, Cohere.GenerateStreamEnd>;
export declare namespace GenerateStreamEnd {
    interface Raw extends GenerateStreamEvent.Raw {
        is_finished: boolean;
        finish_reason?: FinishReason.Raw | null;
        response: GenerateStreamEndResponse.Raw;
    }
}
