import type * as Cohere from "../index";
/**
 * Outputs from a tool. The content should formatted as a JSON object string, or a list of tool content blocks
 */
export type ToolMessageV2Content = string | Cohere.ToolContent[];
