import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { LabelMetric } from "./LabelMetric";
export declare const ClassifyDataMetrics: core.serialization.ObjectSchema<serializers.ClassifyDataMetrics.Raw, Cohere.ClassifyDataMetrics>;
export declare namespace ClassifyDataMetrics {
    interface Raw {
        label_metrics?: LabelMetric.Raw[] | null;
    }
}
