import type * as Cohere from "../index";
export interface TokenizeResponse {
    /** An array of tokens, where each token is an integer. */
    tokens: number[];
    tokenStrings: string[];
    meta?: Cohere.ApiMeta;
}
