import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedInputType: core.serialization.Schema<serializers.EmbedInputType.Raw, Cohere.EmbedInputType>;
export declare namespace EmbedInputType {
    type Raw = "search_document" | "search_query" | "classification" | "clustering" | "image";
}
