import type * as Cohere from "../index";
export interface SummarizeResponse {
    /** Generated ID for the summary */
    id?: string;
    /** Generated summary for the text */
    summary?: string;
    meta?: Cohere.ApiMeta;
}
