import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatTextResponseFormat: core.serialization.ObjectSchema<serializers.ChatTextResponseFormat.Raw, Cohere.ChatTextResponseFormat>;
export declare namespace ChatTextResponseFormat {
    type Raw = {};
}
