import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
import { ClassifyExample } from "../../types/ClassifyExample";
import { ClassifyRequestTruncate } from "../../types/ClassifyRequestTruncate";
export declare const ClassifyRequest: core.serialization.Schema<serializers.ClassifyRequest.Raw, Cohere.ClassifyRequest>;
export declare namespace ClassifyRequest {
    interface Raw {
        inputs: string[];
        examples?: ClassifyExample.Raw[] | null;
        model?: string | null;
        preset?: string | null;
        truncate?: ClassifyRequestTruncate.Raw | null;
    }
}
