import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentStartEventDeltaMessageContentType } from "./ChatContentStartEventDeltaMessageContentType";
export declare const ChatContentStartEventDeltaMessageContent: core.serialization.ObjectSchema<serializers.ChatContentStartEventDeltaMessageContent.Raw, Cohere.ChatContentStartEventDeltaMessageContent>;
export declare namespace ChatContentStartEventDeltaMessageContent {
    interface Raw {
        thinking?: string | null;
        text?: string | null;
        type?: ChatContentStartEventDeltaMessageContentType.Raw | null;
    }
}
