import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatMessageStartEventDelta } from "./ChatMessageStartEventDelta";
import { ChatStreamEventType } from "./ChatStreamEventType";
export declare const ChatMessageStartEvent: core.serialization.ObjectSchema<serializers.ChatMessageStartEvent.Raw, Cohere.ChatMessageStartEvent>;
export declare namespace ChatMessageStartEvent {
    interface Raw extends ChatStreamEventType.Raw {
        id?: string | null;
        delta?: ChatMessageStartEventDelta.Raw | null;
    }
}
