import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolCallV2Function } from "./ToolCallV2Function";
export declare const ToolCallV2: core.serialization.ObjectSchema<serializers.ToolCallV2.Raw, Cohere.ToolCallV2>;
export declare namespace ToolCallV2 {
    interface Raw {
        id: string;
        type: "function";
        function?: ToolCallV2Function.Raw | null;
    }
}
