"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateStreamRequestReturnLikelihoods = void 0;
/**
 * One of `GENERATION|NONE` to specify how and if the token likelihoods are returned with the response. Defaults to `NONE`.
 *
 * If `GENERATION` is selected, the token likelihoods will only be provided for generated text.
 *
 * WARNING: `ALL` is deprecated, and will be removed in a future release.
 */
exports.GenerateStreamRequestReturnLikelihoods = {
    Generation: "GENERATION",
    All: "ALL",
    None: "NONE",
};
