/**
 * @example
 *     {
 *         documents: ["Carson City is the capital city of the American state of Nevada.", "The Commonwealth of the Northern Mariana Islands is a group of islands in the Pacific Ocean. Its capital is Saipan.", "Capitalization or capitalisation in English grammar is the use of a capital letter at the start of a word. English usage varies from capitalization in other languages.", "Washington, D.C. (also known as simply Washington or D.C., and officially as the District of Columbia) is the capital of the United States. It is a federal district.", "Capital punishment has existed in the United States since beforethe United States was a country. As of 2017, capital punishment is legal in 30 of the 50 states."],
 *         query: "What is the capital of the United States?",
 *         topN: 3,
 *         model: "rerank-v3.5"
 *     }
 */
export interface V2RerankRequest {
    /** The identifier of the model to use, eg `rerank-v3.5`. */
    model: string;
    /** The search query */
    query: string;
    /**
     * A list of texts that will be compared to the `query`.
     * For optimal performance we recommend against sending more than 1,000 documents in a single request.
     *
     * **Note**: long documents will automatically be truncated to the value of `max_tokens_per_doc`.
     *
     * **Note**: structured data should be formatted as YAML strings for best performance.
     */
    documents: string[];
    /** Limits the number of returned rerank results to the specified value. If not passed, all the rerank results will be returned. */
    topN?: number;
    /** Defaults to `4096`. Long documents will be automatically truncated to the specified number of tokens. */
    maxTokensPerDoc?: number;
    /**
     * The priority of the request (lower means earlier handling; default 0 highest priority).
     * Higher priority requests are handled first, and dropped last when the system is under load.
     */
    priority?: number;
}
