import { FetchFunction } from './core';
export declare const mapResponseFromBedrock: (streaming: boolean, endpoint: string, version: 1 | 2, obj: {}) => Promise<any>;
export type AwsProps = {
    awsRegion: string;
    awsAccessKey?: string;
    awsSecretKey?: string;
    awsSessionToken?: string;
};
export type AwsPlatform = "sagemaker" | "bedrock";
export type AwsEndpoint = "chat" | "generate" | "embed" | "rerank";
export declare const getUrl: (platform: "bedrock" | "sagemaker", awsRegion: string, model: string, stream: boolean) => string;
export declare const getAuthHeaders: (url: URL, method: string, headers: Record<string, string>, body: unknown, service: AwsPlatform, props: AwsProps) => Promise<Record<string, string>>;
export declare const parseAWSEvent: (line: string) => any;
export declare const fetchOverride: (platform: AwsPlatform, { awsRegion, awsAccessKey, awsSecretKey, awsSessionToken, }: AwsProps) => FetchFunction;
