import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { GenerateStreamEnd } from "./GenerateStreamEnd";
import { GenerateStreamError } from "./GenerateStreamError";
import { GenerateStreamText } from "./GenerateStreamText";
export declare const GenerateStreamedResponse: core.serialization.Schema<serializers.GenerateStreamedResponse.Raw, Cohere.GenerateStreamedResponse>;
export declare namespace GenerateStreamedResponse {
    type Raw = GenerateStreamedResponse.TextGeneration | GenerateStreamedResponse.StreamEnd | GenerateStreamedResponse.StreamError;
    interface TextGeneration extends GenerateStreamText.Raw {
        event_type: "text-generation";
    }
    interface StreamEnd extends GenerateStreamEnd.Raw {
        event_type: "stream-end";
    }
    interface StreamError extends GenerateStreamError.Raw {
        event_type: "stream-error";
    }
}
