import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const SummarizeRequestExtractiveness: core.serialization.Schema<serializers.SummarizeRequestExtractiveness.Raw, Cohere.SummarizeRequestExtractiveness>;
export declare namespace SummarizeRequestExtractiveness {
    type Raw = "low" | "medium" | "high";
}
