import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { Image } from "./Image";
export declare const EmbedFloatsResponse: core.serialization.ObjectSchema<serializers.EmbedFloatsResponse.Raw, Cohere.EmbedFloatsResponse>;
export declare namespace EmbedFloatsResponse {
    interface Raw {
        id: string;
        embeddings: number[][];
        texts: string[];
        images?: Image.Raw[] | null;
        meta?: ApiMeta.Raw | null;
    }
}
