import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { AuthTokenType } from "./AuthTokenType";
export declare const CreateConnectorServiceAuth: core.serialization.ObjectSchema<serializers.CreateConnectorServiceAuth.Raw, Cohere.CreateConnectorServiceAuth>;
export declare namespace CreateConnectorServiceAuth {
    interface Raw {
        type: AuthTokenType.Raw;
        token: string;
    }
}
