import type * as Cohere from "../index";
export interface GenerateStreamEnd extends Cohere.GenerateStreamEvent {
    isFinished: boolean;
    finishReason?: Cohere.FinishReason;
    response: Cohere.GenerateStreamEndResponse;
}
