import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const CompatibleEndpoint: core.serialization.Schema<serializers.CompatibleEndpoint.Raw, Cohere.CompatibleEndpoint>;
export declare namespace CompatibleEndpoint {
    type Raw = "chat" | "embed" | "classify" | "summarize" | "rerank" | "rate" | "generate";
}
