import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatFinishReason } from "./ChatFinishReason";
import { Usage } from "./Usage";
export declare const ChatMessageEndEventDelta: core.serialization.ObjectSchema<serializers.ChatMessageEndEventDelta.Raw, Cohere.ChatMessageEndEventDelta>;
export declare namespace ChatMessageEndEventDelta {
    interface Raw {
        error?: string | null;
        finish_reason?: ChatFinishReason.Raw | null;
        usage?: Usage.Raw | null;
    }
}
