import type * as Cohere from "../index";
export interface ImageUrl {
    /** URL of an image. Can be either a base64 data URI or a web URL. */
    url: string;
    /** Controls the level of detail in image processing. `"auto"` is the default and lets the system choose, `"low"` is faster but less detailed, and `"high"` preserves maximum detail. You can save tokens and speed up responses by using detail: `"low"`. */
    detail?: Cohere.ImageUrlDetail;
}
