/** One of `short`, `medium`, `long`, or `auto` defaults to `auto`. Indicates the approximate length of the summary. If `auto` is selected, the best option will be picked based on the input text. */
export declare const SummarizeRequestLength: {
    readonly Short: "short";
    readonly Medium: "medium";
    readonly Long: "long";
};
export type SummarizeRequestLength = (typeof SummarizeRequestLength)[keyof typeof SummarizeRequestLength];
