/**
 * The possible strategy used to serve a fine-tuned models.
 *
 *  - STRATEGY_UNSPECIFIED: Unspecified strategy.
 *  - STRATEGY_VANILLA: Deprecated: Serve the fine-tuned model on a dedicated GPU.
 *  - STRATEGY_TFEW: Deprecated: Serve the fine-tuned model on a shared GPU.
 */
export declare const Strategy: {
    readonly StrategyUnspecified: "STRATEGY_UNSPECIFIED";
    readonly StrategyVanilla: "STRATEGY_VANILLA";
    readonly StrategyTfew: "STRATEGY_TFEW";
};
export type Strategy = (typeof Strategy)[keyof typeof Strategy];
