import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatContentStartEventDeltaMessageContentType: core.serialization.Schema<serializers.ChatContentStartEventDeltaMessageContentType.Raw, Cohere.ChatContentStartEventDeltaMessageContentType>;
export declare namespace ChatContentStartEventDeltaMessageContentType {
    type Raw = "text" | "thinking";
}
