/**
 * Contains the chunk of the tool call generation in the stream.
 */
export interface ToolCallDelta {
    /** Name of the tool call */
    name?: string;
    /** Index of the tool call generated */
    index?: number;
    /** Chunk of the tool parameters */
    parameters?: string;
    /** Chunk of the tool plan text */
    text?: string;
}
