import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { GenerateStreamEvent } from "./GenerateStreamEvent";
export declare const GenerateStreamText: core.serialization.ObjectSchema<serializers.GenerateStreamText.Raw, Cohere.GenerateStreamText>;
export declare namespace GenerateStreamText {
    interface Raw extends GenerateStreamEvent.Raw {
        text: string;
        index?: number | null;
        is_finished: boolean;
    }
}
