import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
export declare const TokenizeResponse: core.serialization.ObjectSchema<serializers.TokenizeResponse.Raw, Cohere.TokenizeResponse>;
export declare namespace TokenizeResponse {
    interface Raw {
        tokens: number[];
        token_strings: string[];
        meta?: ApiMeta.Raw | null;
    }
}
