import type * as Cohere from "../../../../../index";
/**
 * Response to a request to get a fine-tuned model.
 */
export interface GetFinetunedModelResponse {
    /** Information about the fine-tuned model. */
    finetunedModel?: Cohere.finetuning.FinetunedModel;
}
