"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectorAuthStatus = void 0;
/** The OAuth status for the user making the request. One of ["valid", "expired", ""]. Empty string (field is omitted) means the user has not authorized the connector yet. */
exports.ConnectorAuthStatus = {
    Valid: "valid",
    Expired: "expired",
};
