/**
 * @example
 *     {
 *         pageSize: 1,
 *         pageToken: "page_token"
 *     }
 */
export interface FinetuningListTrainingStepMetricsRequest {
    /**
     * Maximum number of results to be returned by the server. If 0, defaults to
     * 50.
     */
    pageSize?: number;
    /** Request a specific page of the list results. */
    pageToken?: string;
}
