import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatDocument: core.serialization.Schema<serializers.ChatDocument.Raw, Cohere.ChatDocument>;
export declare namespace ChatDocument {
    type Raw = Record<string, string>;
}
