import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const SingleGenerationTokenLikelihoodsItem: core.serialization.ObjectSchema<serializers.SingleGenerationTokenLikelihoodsItem.Raw, Cohere.SingleGenerationTokenLikelihoodsItem>;
export declare namespace SingleGenerationTokenLikelihoodsItem {
    interface Raw {
        token: string;
        likelihood: number;
    }
}
