import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatRequestCitationQuality: core.serialization.Schema<serializers.ChatRequestCitationQuality.Raw, Cohere.ChatRequestCitationQuality>;
export declare namespace ChatRequestCitationQuality {
    type Raw = "ENABLED" | "DISABLED" | "FAST" | "ACCURATE" | "OFF";
}
