import type * as Cohere from "../../../../../index";
/**
 * The fine-tuning hyperparameters.
 */
export interface Hyperparameters {
    /**
     * Stops training if the loss metric does not improve beyond the value of
     * `early_stopping_threshold` after this many times of evaluation.
     */
    earlyStoppingPatience?: number;
    /** How much the loss must improve to prevent early stopping. */
    earlyStoppingThreshold?: number;
    /**
     * The batch size is the number of training examples included in a single
     * training pass.
     */
    trainBatchSize?: number;
    /** The number of epochs to train for. */
    trainEpochs?: number;
    /** The learning rate to be used during training. */
    learningRate?: number;
    /**
     * Controls the scaling factor for LoRA updates. Higher values make the
     * updates more impactful.
     */
    loraAlpha?: number;
    /**
     * Specifies the rank for low-rank matrices. Lower ranks reduce parameters
     * but may limit model flexibility.
     */
    loraRank?: number;
    /** The combination of LoRA modules to target. */
    loraTargetModules?: Cohere.finetuning.LoraTargetModules;
}
