import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const Strategy: core.serialization.Schema<serializers.finetuning.Strategy.Raw, Cohere.finetuning.Strategy>;
export declare namespace Strategy {
    type Raw = "STRATEGY_UNSPECIFIED" | "STRATEGY_VANILLA" | "STRATEGY_TFEW";
}
