import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ConnectorAuthStatus } from "./ConnectorAuthStatus";
import { ConnectorOAuth } from "./ConnectorOAuth";
export declare const Connector: core.serialization.ObjectSchema<serializers.Connector.Raw, Cohere.Connector>;
export declare namespace Connector {
    interface Raw {
        id: string;
        organization_id?: string | null;
        name: string;
        description?: string | null;
        url?: string | null;
        created_at: string;
        updated_at: string;
        excludes?: string[] | null;
        auth_type?: string | null;
        oauth?: ConnectorOAuth.Raw | null;
        auth_status?: ConnectorAuthStatus.Raw | null;
        active?: boolean | null;
        continue_on_failure?: boolean | null;
    }
}
