export declare const EmbeddingType: {
    readonly Float: "float";
    readonly Int8: "int8";
    readonly Uint8: "uint8";
    readonly Binary: "binary";
    readonly Ubinary: "ubinary";
    readonly Base64: "base64";
};
export type EmbeddingType = (typeof EmbeddingType)[keyof typeof EmbeddingType];
