import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ApiMetaBilledUnits: core.serialization.ObjectSchema<serializers.ApiMetaBilledUnits.Raw, Cohere.ApiMetaBilledUnits>;
export declare namespace ApiMetaBilledUnits {
    interface Raw {
        images?: number | null;
        input_tokens?: number | null;
        output_tokens?: number | null;
        search_units?: number | null;
        classifications?: number | null;
    }
}
