"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.SummarizeRequestFormat = void 0;
/** One of `paragraph`, `bullets`, or `auto`, defaults to `auto`. Indicates the style in which the summary will be delivered - in a free form paragraph or in bullet points. If `auto` is selected, the best option will be picked based on the input text. */
exports.SummarizeRequestFormat = {
    Paragraph: "paragraph",
    Bullets: "bullets",
};
