import type * as Cohere from "../index";
export interface Generation {
    id: string;
    /** Prompt used for generations. */
    prompt?: string;
    /** List of generated results */
    generations: Cohere.SingleGeneration[];
    meta?: Cohere.ApiMeta;
}
