import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatStreamEvent: core.serialization.ObjectSchema<serializers.ChatStreamEvent.Raw, Cohere.ChatStreamEvent>;
export declare namespace ChatStreamEvent {
    type Raw = {};
}
