/** The OAuth status for the user making the request. One of ["valid", "expired", ""]. Empty string (field is omitted) means the user has not authorized the connector yet. */
export declare const ConnectorAuthStatus: {
    readonly Valid: "valid";
    readonly Expired: "expired";
};
export type ConnectorAuthStatus = (typeof ConnectorAuthStatus)[keyof typeof ConnectorAuthStatus];
