import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatTextContent } from "./ChatTextContent";
import { ChatThinkingContent } from "./ChatThinkingContent";
export declare const AssistantMessageV2ContentItem: core.serialization.Schema<serializers.AssistantMessageV2ContentItem.Raw, Cohere.AssistantMessageV2ContentItem>;
export declare namespace AssistantMessageV2ContentItem {
    type Raw = AssistantMessageV2ContentItem.Text | AssistantMessageV2ContentItem.Thinking;
    interface Text extends ChatTextContent.Raw {
        type: "text";
    }
    interface Thinking extends ChatThinkingContent.Raw {
        type: "thinking";
    }
}
