import type * as Cohere from "../index";
export interface EmbedJob {
    /** ID of the embed job */
    jobId: string;
    /** The name of the embed job */
    name?: string;
    /** The status of the embed job */
    status: Cohere.EmbedJobStatus;
    /** The creation date of the embed job */
    createdAt: Date;
    /** ID of the input dataset */
    inputDatasetId: string;
    /** ID of the resulting output dataset */
    outputDatasetId?: string;
    /** ID of the model used to embed */
    model: string;
    /** The truncation option used */
    truncate: Cohere.EmbedJobTruncate;
    meta?: Cohere.ApiMeta;
}
