import type * as Cohere from "../index";
/**
 * A streamed event delta which signifies a tool call has started streaming.
 */
export interface ChatToolCallStartEvent extends Cohere.ChatStreamEventType {
    index?: number;
    delta?: Cohere.ChatToolCallStartEventDelta;
}
