import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { Document } from "./Document";
export declare const DocumentContent: core.serialization.ObjectSchema<serializers.DocumentContent.Raw, Cohere.DocumentContent>;
export declare namespace DocumentContent {
    interface Raw {
        document: Document.Raw;
    }
}
