import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolCallV2 } from "./ToolCallV2";
export declare const ChatToolCallStartEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatToolCallStartEventDeltaMessage.Raw, Cohere.ChatToolCallStartEventDeltaMessage>;
export declare namespace ChatToolCallStartEventDeltaMessage {
    interface Raw {
        tool_calls?: ToolCallV2.Raw | null;
    }
}
