import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatContentDeltaEventDeltaMessageContent: core.serialization.ObjectSchema<serializers.ChatContentDeltaEventDeltaMessageContent.Raw, Cohere.ChatContentDeltaEventDeltaMessageContent>;
export declare namespace ChatContentDeltaEventDeltaMessageContent {
    interface Raw {
        thinking?: string | null;
        text?: string | null;
    }
}
