"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Status = void 0;
/**
 * The possible stages of a fine-tuned model life-cycle.
 *
 *  - STATUS_UNSPECIFIED: Unspecified status.
 *  - STATUS_FINETUNING: The fine-tuned model is being fine-tuned.
 *  - STATUS_DEPLOYING_API: Deprecated: The fine-tuned model is being deployed.
 *  - STATUS_READY: The fine-tuned model is ready to receive requests.
 *  - STATUS_FAILED: The fine-tuned model failed.
 *  - STATUS_DELETED: The fine-tuned model was deleted.
 *  - STATUS_TEMPORARILY_OFFLINE: Deprecated: The fine-tuned model is temporarily unavailable.
 *  - STATUS_PAUSED: Deprecated: The fine-tuned model is paused (Vanilla only).
 *  - STATUS_QUEUED: The fine-tuned model is queued for training.
 */
exports.Status = {
    StatusUnspecified: "STATUS_UNSPECIFIED",
    StatusFinetuning: "STATUS_FINETUNING",
    StatusDeployingApi: "STATUS_DEPLOYING_API",
    StatusReady: "STATUS_READY",
    StatusFailed: "STATUS_FAILED",
    StatusDeleted: "STATUS_DELETED",
    StatusTemporarilyOffline: "STATUS_TEMPORARILY_OFFLINE",
    StatusPaused: "STATUS_PAUSED",
    StatusQueued: "STATUS_QUEUED",
};
