"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthTokenType = void 0;
/** The token_type specifies the way the token is passed in the Authorization header. Valid values are "bearer", "basic", and "noscheme". */
exports.AuthTokenType = {
    Bearer: "bearer",
    Basic: "basic",
    Noscheme: "noscheme",
};
