import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { EmbedByTypeResponse } from "./EmbedByTypeResponse";
import { EmbedFloatsResponse } from "./EmbedFloatsResponse";
export declare const EmbedResponse: core.serialization.Schema<serializers.EmbedResponse.Raw, Cohere.EmbedResponse>;
export declare namespace EmbedResponse {
    type Raw = EmbedResponse.EmbeddingsFloats | EmbedResponse.EmbeddingsByType;
    interface EmbeddingsFloats extends EmbedFloatsResponse.Raw {
        response_type: "embeddings_floats";
    }
    interface EmbeddingsByType extends EmbedByTypeResponse.Raw {
        response_type: "embeddings_by_type";
    }
}
