import type * as Cohere from "../index";
export interface EmbedFloatsResponse {
    id: string;
    /** An array of embeddings, where each embedding is an array of floats. The length of the `embeddings` array will be the same as the length of the original `texts` array. */
    embeddings: number[][];
    /** The text entries for which embeddings were returned. */
    texts: string[];
    /** The image entries for which embeddings were returned. */
    images?: Cohere.Image[];
    meta?: Cohere.ApiMeta;
}
