import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const BaseType: core.serialization.Schema<serializers.finetuning.BaseType.Raw, Cohere.finetuning.BaseType>;
export declare namespace BaseType {
    type Raw = "BASE_TYPE_UNSPECIFIED" | "BASE_TYPE_GENERATIVE" | "BASE_TYPE_CLASSIFICATION" | "BASE_TYPE_RERANK" | "BASE_TYPE_CHAT";
}
