import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const OAuthAuthorizeResponse: core.serialization.ObjectSchema<serializers.OAuthAuthorizeResponse.Raw, Cohere.OAuthAuthorizeResponse>;
export declare namespace OAuthAuthorizeResponse {
    interface Raw {
        redirect_url?: string | null;
    }
}
