import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentDeltaEventDeltaMessageContent } from "./ChatContentDeltaEventDeltaMessageContent";
export declare const ChatContentDeltaEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatContentDeltaEventDeltaMessage.Raw, Cohere.ChatContentDeltaEventDeltaMessage>;
export declare namespace ChatContentDeltaEventDeltaMessage {
    interface Raw {
        content?: ChatContentDeltaEventDeltaMessageContent.Raw | null;
    }
}
