"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateConnectorRequest = exports.CreateConnectorRequest = void 0;
var CreateConnectorRequest_1 = require("./CreateConnectorRequest");
Object.defineProperty(exports, "CreateConnectorRequest", { enumerable: true, get: function () { return CreateConnectorRequest_1.CreateConnectorRequest; } });
var UpdateConnectorRequest_1 = require("./UpdateConnectorRequest");
Object.defineProperty(exports, "UpdateConnectorRequest", { enumerable: true, get: function () { return UpdateConnectorRequest_1.UpdateConnectorRequest; } });
