import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { CompatibleEndpoint } from "./CompatibleEndpoint";
export declare const GetModelResponse: core.serialization.ObjectSchema<serializers.GetModelResponse.Raw, Cohere.GetModelResponse>;
export declare namespace GetModelResponse {
    interface Raw {
        name?: string | null;
        is_deprecated?: boolean | null;
        endpoints?: CompatibleEndpoint.Raw[] | null;
        finetuned?: boolean | null;
        context_length?: number | null;
        tokenizer_url?: string | null;
        default_endpoints?: CompatibleEndpoint.Raw[] | null;
        features?: string[] | null;
    }
}
