import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const Response: core.serialization.Schema<serializers.datasets.delete.Response.Raw, Record<string, unknown>>;
export declare namespace Response {
    type Raw = Record<string, unknown>;
}
