import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const LabelMetric: core.serialization.ObjectSchema<serializers.LabelMetric.Raw, Cohere.LabelMetric>;
export declare namespace LabelMetric {
    interface Raw {
        total_examples?: number | null;
        label?: string | null;
        samples?: string[] | null;
    }
}
