import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const CitationOptionsMode: core.serialization.Schema<serializers.CitationOptionsMode.Raw, Cohere.CitationOptionsMode>;
export declare namespace CitationOptionsMode {
    type Raw = "ENABLED" | "DISABLED" | "FAST" | "ACCURATE" | "OFF";
}
