import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { Connector } from "./Connector";
export declare const ListConnectorsResponse: core.serialization.ObjectSchema<serializers.ListConnectorsResponse.Raw, Cohere.ListConnectorsResponse>;
export declare namespace ListConnectorsResponse {
    interface Raw {
        connectors: Connector.Raw[];
        total_count?: number | null;
    }
}
