/** The type of classification performed */
export declare const ClassifyResponseClassificationsItemClassificationType: {
    readonly SingleLabel: "single-label";
    readonly MultiLabel: "multi-label";
};
export type ClassifyResponseClassificationsItemClassificationType = (typeof ClassifyResponseClassificationsItemClassificationType)[keyof typeof ClassifyResponseClassificationsItemClassificationType];
