import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { AssistantMessageV2ContentItem } from "./AssistantMessageV2ContentItem";
export declare const AssistantMessageV2Content: core.serialization.Schema<serializers.AssistantMessageV2Content.Raw, Cohere.AssistantMessageV2Content>;
export declare namespace AssistantMessageV2Content {
    type Raw = string | AssistantMessageV2ContentItem.Raw[];
}
