import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatRequestPromptTruncation: core.serialization.Schema<serializers.ChatRequestPromptTruncation.Raw, Cohere.ChatRequestPromptTruncation>;
export declare namespace ChatRequestPromptTruncation {
    type Raw = "OFF" | "AUTO" | "AUTO_PRESERVE_ORDER";
}
