import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const DatasetsGetUsageResponse: core.serialization.ObjectSchema<serializers.DatasetsGetUsageResponse.Raw, Cohere.DatasetsGetUsageResponse>;
export declare namespace DatasetsGetUsageResponse {
    interface Raw {
        organization_usage?: number | null;
    }
}
