import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
export declare const CreateEmbedJobResponse: core.serialization.ObjectSchema<serializers.CreateEmbedJobResponse.Raw, Cohere.CreateEmbedJobResponse>;
export declare namespace CreateEmbedJobResponse {
    interface Raw {
        job_id: string;
        meta?: ApiMeta.Raw | null;
    }
}
