import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ThinkingType: core.serialization.Schema<serializers.ThinkingType.Raw, Cohere.ThinkingType>;
export declare namespace ThinkingType {
    type Raw = "enabled" | "disabled";
}
