import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ClassifyResponseClassificationsItemClassificationType: core.serialization.Schema<serializers.ClassifyResponseClassificationsItemClassificationType.Raw, Cohere.ClassifyResponseClassificationsItemClassificationType>;
export declare namespace ClassifyResponseClassificationsItemClassificationType {
    type Raw = "single-label" | "multi-label";
}
