export interface BasicAuth {
    username: string;
    password: string;
}
export declare const BasicAuth: {
    toAuthorizationHeader: (basicAuth: BasicAuth | undefined) => string | undefined;
    fromAuthorizationHeader: (header: string) => BasicAuth;
};
