import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatTextContent } from "./ChatTextContent";
import { ImageContent } from "./ImageContent";
export declare const Content: core.serialization.Schema<serializers.Content.Raw, Cohere.Content>;
export declare namespace Content {
    type Raw = Content.Text | Content.ImageUrl;
    interface Text extends ChatTextContent.Raw {
        type: "text";
    }
    interface ImageUrl extends ImageContent.Raw {
        type: "image_url";
    }
}
