import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatThinkingContent: core.serialization.ObjectSchema<serializers.ChatThinkingContent.Raw, Cohere.ChatThinkingContent>;
export declare namespace ChatThinkingContent {
    interface Raw {
        thinking: string;
    }
}
