import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedJobStatus: core.serialization.Schema<serializers.EmbedJobStatus.Raw, Cohere.EmbedJobStatus>;
export declare namespace EmbedJobStatus {
    type Raw = "processing" | "complete" | "cancelling" | "cancelled" | "failed";
}
