import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatTextResponseFormat } from "./ChatTextResponseFormat";
import { JsonResponseFormat } from "./JsonResponseFormat";
export declare const ResponseFormat: core.serialization.Schema<serializers.ResponseFormat.Raw, Cohere.ResponseFormat>;
export declare namespace ResponseFormat {
    type Raw = ResponseFormat.Text | ResponseFormat.JsonObject;
    interface Text extends ChatTextResponseFormat.Raw {
        type: "text";
    }
    interface JsonObject extends JsonResponseFormat.Raw {
        type: "json_object";
    }
}
