import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { RerankResponseResultsItem } from "./RerankResponseResultsItem";
export declare const RerankResponse: core.serialization.ObjectSchema<serializers.RerankResponse.Raw, Cohere.RerankResponse>;
export declare namespace RerankResponse {
    interface Raw {
        id?: string | null;
        results: RerankResponseResultsItem.Raw[];
        meta?: ApiMeta.Raw | null;
    }
}
