import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const V2ChatRequestToolChoice: core.serialization.Schema<serializers.V2ChatRequestToolChoice.Raw, Cohere.V2ChatRequestToolChoice>;
export declare namespace V2ChatRequestToolChoice {
    type Raw = "REQUIRED" | "NONE";
}
