/**
 * The evaluation metrics at a given step of the training of a fine-tuned model.
 */
export interface TrainingStepMetrics {
    /** Creation timestamp. */
    createdAt?: Date;
    /** Step number. */
    stepNumber?: number;
    /** Map of names and values for each evaluation metrics. */
    metrics?: Record<string, number>;
}
