/**
 * The function to be executed.
 */
export interface ToolV2Function {
    /** The name of the function. */
    name: string;
    /** The description of the function. */
    description?: string;
    /** The parameters of the function as a JSON schema. */
    parameters: Record<string, unknown>;
}
