import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatCitation } from "./ChatCitation";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatCitationGenerationEvent: core.serialization.ObjectSchema<serializers.ChatCitationGenerationEvent.Raw, Cohere.ChatCitationGenerationEvent>;
export declare namespace ChatCitationGenerationEvent {
    interface Raw extends ChatStreamEvent.Raw {
        citations: ChatCitation.Raw[];
    }
}
