/**
 * @example
 *     {
 *         pageSize: 1,
 *         pageToken: "page_token",
 *         orderBy: "order_by"
 *     }
 */
export interface BatchesListBatchesRequest {
    /**
     * The maximum number of batches to return. The service may return fewer than
     * this value.
     * If unspecified, at most 50 batches will be returned.
     * The maximum value is 1000; values above 1000 will be coerced to 1000.
     */
    pageSize?: number;
    /**
     * A page token, received from a previous `ListBatches` call.
     * Provide this to retrieve the subsequent page.
     */
    pageToken?: string;
    /**
     * Batches can be ordered by creation time or last updated time.
     * Use `created_at` for creation time or `updated_at` for last updated time.
     */
    orderBy?: string;
}
