import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { FinishReason } from "./FinishReason";
import { GenerateStreamEvent } from "./GenerateStreamEvent";
export declare const GenerateStreamError: core.serialization.ObjectSchema<serializers.GenerateStreamError.Raw, Cohere.GenerateStreamError>;
export declare namespace GenerateStreamError {
    interface Raw extends GenerateStreamEvent.Raw {
        index?: number | null;
        is_finished: boolean;
        finish_reason: FinishReason.Raw;
        err: string;
    }
}
