import type * as Cohere from "../index";
export interface ChatSearchQueriesGenerationEvent extends Cohere.ChatStreamEvent {
    /** Generated search queries, meant to be used as part of the RAG flow. */
    searchQueries: Cohere.ChatSearchQuery[];
}
