"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.V2ChatStreamRequestToolChoice = void 0;
/**
 * Used to control whether or not the model will be forced to use a tool when answering. When `REQUIRED` is specified, the model will be forced to use at least one of the user-defined tools, and the `tools` parameter must be passed in the request.
 * When `NONE` is specified, the model will be forced **not** to use one of the specified tools, and give a direct response.
 * If tool_choice isn't specified, then the model is free to choose whether to use the specified tools or not.
 *
 * **Note**: This parameter is only compatible with models [Command-r7b](https://docs.cohere.com/v2/docs/command-r7b) and newer.
 */
exports.V2ChatStreamRequestToolChoice = {
    Required: "REQUIRED",
    None: "NONE",
};
