import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatToolCallDeltaEventDeltaMessageToolCalls } from "./ChatToolCallDeltaEventDeltaMessageToolCalls";
export declare const ChatToolCallDeltaEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatToolCallDeltaEventDeltaMessage.Raw, Cohere.ChatToolCallDeltaEventDeltaMessage>;
export declare namespace ChatToolCallDeltaEventDeltaMessage {
    interface Raw {
        tool_calls?: ChatToolCallDeltaEventDeltaMessageToolCalls.Raw | null;
    }
}
