import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ApiMeta } from "./ApiMeta";
import { EmbedJobStatus } from "./EmbedJobStatus";
import { EmbedJobTruncate } from "./EmbedJobTruncate";
export declare const EmbedJob: core.serialization.ObjectSchema<serializers.EmbedJob.Raw, Cohere.EmbedJob>;
export declare namespace EmbedJob {
    interface Raw {
        job_id: string;
        name?: string | null;
        status: EmbedJobStatus.Raw;
        created_at: string;
        input_dataset_id: string;
        output_dataset_id?: string | null;
        model: string;
        truncate: EmbedJobTruncate.Raw;
        meta?: ApiMeta.Raw | null;
    }
}
