import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ParseInfo: core.serialization.ObjectSchema<serializers.ParseInfo.Raw, Cohere.ParseInfo>;
export declare namespace ParseInfo {
    interface Raw {
        separator?: string | null;
        delimiter?: string | null;
    }
}
