import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const GenerateStreamRequestTruncate: core.serialization.Schema<serializers.GenerateStreamRequestTruncate.Raw, Cohere.GenerateStreamRequestTruncate>;
export declare namespace GenerateStreamRequestTruncate {
    type Raw = "NONE" | "START" | "END";
}
