import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const CreateConnectorOAuth: core.serialization.ObjectSchema<serializers.CreateConnectorOAuth.Raw, Cohere.CreateConnectorOAuth>;
export declare namespace CreateConnectorOAuth {
    interface Raw {
        client_id?: string | null;
        client_secret?: string | null;
        authorize_url?: string | null;
        token_url?: string | null;
        scope?: string | null;
    }
}
