import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { EmbedImageUrl } from "./EmbedImageUrl";
export declare const EmbedImage: core.serialization.ObjectSchema<serializers.EmbedImage.Raw, Cohere.EmbedImage>;
export declare namespace EmbedImage {
    interface Raw {
        image_url?: EmbedImageUrl.Raw | null;
    }
}
