import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const DeleteConnectorResponse: core.serialization.Schema<serializers.DeleteConnectorResponse.Raw, Cohere.DeleteConnectorResponse>;
export declare namespace DeleteConnectorResponse {
    type Raw = Record<string, unknown>;
}
