import type * as Cohere from "../index";
/**
 * A streamed event which signifies that the chat message has ended.
 */
export interface ChatMessageEndEvent extends Cohere.ChatStreamEventType {
    id?: string;
    delta?: Cohere.ChatMessageEndEventDelta;
}
