import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { Batch } from "./Batch";
export declare const ListBatchesResponse: core.serialization.ObjectSchema<serializers.ListBatchesResponse.Raw, Cohere.ListBatchesResponse>;
export declare namespace ListBatchesResponse {
    interface Raw {
        batches?: Batch.Raw[] | null;
        next_page_token?: string | null;
    }
}
