/**
 * The reason a chat request has finished.
 *
 * - **complete**: The model finished sending a complete message.
 * - **max_tokens**: The number of generated tokens exceeded the model's context length or the value specified via the `max_tokens` parameter.
 * - **stop_sequence**: One of the provided `stop_sequence` entries was reached in the model's generation.
 * - **tool_call**: The model generated a Tool Call and is expecting a Tool Message in return
 * - **error**: The generation failed due to an internal error
 * - **timeout**: The generation was stopped because it exceeded the allowed time limit.
 */
export declare const ChatFinishReason: {
    readonly Complete: "COMPLETE";
    readonly StopSequence: "STOP_SEQUENCE";
    readonly MaxTokens: "MAX_TOKENS";
    readonly ToolCall: "TOOL_CALL";
    readonly Error: "ERROR";
    readonly Timeout: "TIMEOUT";
};
export type ChatFinishReason = (typeof ChatFinishReason)[keyof typeof ChatFinishReason];
