/**
 * @example
 *     {
 *         tokens: [10002, 2261, 2012, 8, 2792, 43],
 *         model: "command"
 *     }
 */
export interface DetokenizeRequest {
    /** The list of tokens to be detokenized. */
    tokens: number[];
    /** An optional parameter to provide the model name. This will ensure that the detokenization is done by the tokenizer used by that model. */
    model: string;
}
