"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatContentStartEventDeltaMessageContentType = void 0;
exports.ChatContentStartEventDeltaMessageContentType = {
    Text: "text",
    Thinking: "thinking",
};
