import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEventType } from "./ChatStreamEventType";
import { ChatToolCallStartEventDelta } from "./ChatToolCallStartEventDelta";
export declare const ChatToolCallStartEvent: core.serialization.ObjectSchema<serializers.ChatToolCallStartEvent.Raw, Cohere.ChatToolCallStartEvent>;
export declare namespace ChatToolCallStartEvent {
    interface Raw extends ChatStreamEventType.Raw {
        index?: number | null;
        delta?: ChatToolCallStartEventDelta.Raw | null;
    }
}
