import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const CancelBatchResponse: core.serialization.Schema<serializers.CancelBatchResponse.Raw, Cohere.CancelBatchResponse>;
export declare namespace CancelBatchResponse {
    type Raw = Record<string, unknown>;
}
