import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatToolSource: core.serialization.ObjectSchema<serializers.ChatToolSource.Raw, Cohere.ChatToolSource>;
export declare namespace ChatToolSource {
    interface Raw {
        id?: string | null;
        tool_output?: Record<string, unknown> | null;
    }
}
