import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { DatasetPart } from "./DatasetPart";
import { DatasetType } from "./DatasetType";
import { DatasetValidationStatus } from "./DatasetValidationStatus";
export declare const Dataset: core.serialization.ObjectSchema<serializers.Dataset.Raw, Cohere.Dataset>;
export declare namespace Dataset {
    interface Raw {
        id: string;
        name: string;
        created_at: string;
        updated_at: string;
        dataset_type: DatasetType.Raw;
        validation_status: DatasetValidationStatus.Raw;
        validation_error?: string | null;
        schema?: string | null;
        required_fields?: string[] | null;
        preserve_fields?: string[] | null;
        dataset_parts?: DatasetPart.Raw[] | null;
        validation_warnings?: string[] | null;
    }
}
