import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const Status: core.serialization.Schema<serializers.finetuning.Status.Raw, Cohere.finetuning.Status>;
export declare namespace Status {
    type Raw = "STATUS_UNSPECIFIED" | "STATUS_FINETUNING" | "STATUS_DEPLOYING_API" | "STATUS_READY" | "STATUS_FAILED" | "STATUS_DELETED" | "STATUS_TEMPORARILY_OFFLINE" | "STATUS_PAUSED" | "STATUS_QUEUED";
}
