import type * as Cohere from "../../../../../api/index";
import * as core from "../../../../../core";
import type * as serializers from "../../../../index";
import { EmbeddingType } from "../../../../types/EmbeddingType";
import { EmbedInputType } from "../../../../types/EmbedInputType";
import { CreateEmbedJobRequestTruncate } from "../../types/CreateEmbedJobRequestTruncate";
export declare const CreateEmbedJobRequest: core.serialization.Schema<serializers.CreateEmbedJobRequest.Raw, Cohere.CreateEmbedJobRequest>;
export declare namespace CreateEmbedJobRequest {
    interface Raw {
        model: string;
        dataset_id: string;
        input_type: EmbedInputType.Raw;
        name?: string | null;
        embedding_types?: EmbeddingType.Raw[] | null;
        truncate?: CreateEmbedJobRequestTruncate.Raw | null;
    }
}
