import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ToolParameterDefinitionsValue: core.serialization.ObjectSchema<serializers.ToolParameterDefinitionsValue.Raw, Cohere.ToolParameterDefinitionsValue>;
export declare namespace ToolParameterDefinitionsValue {
    interface Raw {
        description?: string | null;
        type: string;
        required?: boolean | null;
    }
}
