import type * as Cohere from "../index";
export interface ListModelsResponse {
    models: Cohere.GetModelResponse[];
    /** A token to retrieve the next page of results. Provide in the page_token parameter of the next request. */
    nextPageToken?: string;
}
