import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
import { FinetunedModel } from "./FinetunedModel";
export declare const UpdateFinetunedModelResponse: core.serialization.ObjectSchema<serializers.finetuning.UpdateFinetunedModelResponse.Raw, Cohere.finetuning.UpdateFinetunedModelResponse>;
export declare namespace UpdateFinetunedModelResponse {
    interface Raw {
        finetuned_model?: FinetunedModel.Raw | null;
    }
}
