import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
import { Status } from "./Status";
export declare const Event: core.serialization.ObjectSchema<serializers.finetuning.Event.Raw, Cohere.finetuning.Event>;
export declare namespace Event {
    interface Raw {
        user_id?: string | null;
        status?: Status.Raw | null;
        created_at?: string | null;
    }
}
