import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEventType } from "./ChatStreamEventType";
export declare const ChatContentEndEvent: core.serialization.ObjectSchema<serializers.ChatContentEndEvent.Raw, Cohere.ChatContentEndEvent>;
export declare namespace ChatContentEndEvent {
    interface Raw extends ChatStreamEventType.Raw {
        index?: number | null;
    }
}
