import type * as Cohere from "../../../../index";
/**
 * @example
 *     {
 *         datasetType: "datasetType",
 *         before: new Date("2024-01-15T09:30:00.000Z"),
 *         after: new Date("2024-01-15T09:30:00.000Z"),
 *         limit: 1.1,
 *         offset: 1.1,
 *         validationStatus: "unknown"
 *     }
 */
export interface DatasetsListRequest {
    /** optional filter by dataset type */
    datasetType?: string;
    /** optional filter before a date */
    before?: Date;
    /** optional filter after a date */
    after?: Date;
    /** optional limit to number of results */
    limit?: number;
    /** optional offset to start of results */
    offset?: number;
    /** optional filter by validation status */
    validationStatus?: Cohere.DatasetValidationStatus;
}
