/** One of the Cohere API endpoints that the model can be used with. */
export declare const CompatibleEndpoint: {
    readonly Chat: "chat";
    readonly Embed: "embed";
    readonly Classify: "classify";
    readonly Summarize: "summarize";
    readonly Rerank: "rerank";
    readonly Rate: "rate";
    readonly Generate: "generate";
};
export type CompatibleEndpoint = (typeof CompatibleEndpoint)[keyof typeof CompatibleEndpoint];
