import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatToolCallDeltaEventDeltaMessage } from "./ChatToolCallDeltaEventDeltaMessage";
export declare const ChatToolCallDeltaEventDelta: core.serialization.ObjectSchema<serializers.ChatToolCallDeltaEventDelta.Raw, Cohere.ChatToolCallDeltaEventDelta>;
export declare namespace ChatToolCallDeltaEventDelta {
    interface Raw {
        message?: ChatToolCallDeltaEventDeltaMessage.Raw | null;
    }
}
