import type * as Cohere from "../index";
/**
 * A message from the assistant role can contain text and tool call information.
 */
export interface AssistantMessageResponse {
    role: "assistant";
    toolCalls?: Cohere.ToolCallV2[];
    /** A chain-of-thought style reflection and plan that the model generates when working with Tools. */
    toolPlan?: string;
    content?: Cohere.AssistantMessageResponseContentItem[];
    citations?: Cohere.Citation[];
}
