"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThinkingType = void 0;
/** Reasoning is enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`. */
exports.ThinkingType = {
    Enabled: "enabled",
    Disabled: "disabled",
};
