import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { SingleGenerationInStream } from "./SingleGenerationInStream";
export declare const GenerateStreamEndResponse: core.serialization.ObjectSchema<serializers.GenerateStreamEndResponse.Raw, Cohere.GenerateStreamEndResponse>;
export declare namespace GenerateStreamEndResponse {
    interface Raw {
        id: string;
        prompt?: string | null;
        generations?: SingleGenerationInStream.Raw[] | null;
    }
}
