/**
 * The Weights & Biases configuration.
 */
export interface WandbConfig {
    /** The WandB project name to be used during training. */
    project: string;
    /** The WandB API key to be used during training. */
    apiKey: string;
    /** The WandB entity name to be used during training. */
    entity?: string;
}
