import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const SummarizeRequestFormat: core.serialization.Schema<serializers.SummarizeRequestFormat.Raw, Cohere.SummarizeRequestFormat>;
export declare namespace SummarizeRequestFormat {
    type Raw = "paragraph" | "bullets";
}
