import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { Connector } from "./Connector";
export declare const CreateConnectorResponse: core.serialization.ObjectSchema<serializers.CreateConnectorResponse.Raw, Cohere.CreateConnectorResponse>;
export declare namespace CreateConnectorResponse {
    interface Raw {
        connector: Connector.Raw;
    }
}
