import type * as Cohere from "../index";
/**
 * A source object containing information about the source of the data cited.
 */
export type Source = Cohere.Source.Tool | Cohere.Source.Document;
export declare namespace Source {
    interface Tool extends Cohere.ChatToolSource {
        type: "tool";
    }
    interface Document extends Cohere.ChatDocumentSource {
        type: "document";
    }
}
