import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
export declare const TokenizeRequest: core.serialization.Schema<serializers.TokenizeRequest.Raw, Cohere.TokenizeRequest>;
export declare namespace TokenizeRequest {
    interface Raw {
        text: string;
        model: string;
    }
}
