/**
 * Specifies the type of input passed to the model. Required for embedding models v3 and higher.
 *
 * - `"search_document"`: Used for embeddings stored in a vector database for search use-cases.
 * - `"search_query"`: Used for embeddings of search queries run against a vector DB to find relevant documents.
 * - `"classification"`: Used for embeddings passed through a text classifier.
 * - `"clustering"`: Used for the embeddings run through a clustering algorithm.
 * - `"image"`: Used for embeddings with image input.
 */
export declare const EmbedInputType: {
    readonly SearchDocument: "search_document";
    readonly SearchQuery: "search_query";
    readonly Classification: "classification";
    readonly Clustering: "clustering";
    readonly Image: "image";
};
export type EmbedInputType = (typeof EmbedInputType)[keyof typeof EmbedInputType];
