import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedByTypeResponseEmbeddings: core.serialization.ObjectSchema<serializers.EmbedByTypeResponseEmbeddings.Raw, Cohere.EmbedByTypeResponseEmbeddings>;
export declare namespace EmbedByTypeResponseEmbeddings {
    interface Raw {
        float?: number[][] | null;
        int8?: number[][] | null;
        uint8?: number[][] | null;
        binary?: number[][] | null;
        ubinary?: number[][] | null;
        base64?: string[] | null;
    }
}
