import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { FinishReason } from "./FinishReason";
export declare const SingleGenerationInStream: core.serialization.ObjectSchema<serializers.SingleGenerationInStream.Raw, Cohere.SingleGenerationInStream>;
export declare namespace SingleGenerationInStream {
    interface Raw {
        id: string;
        text: string;
        index?: number | null;
        finish_reason: FinishReason.Raw;
    }
}
