/** The type of citation which indicates what part of the response the citation is for. */
export declare const ChatCitationType: {
    readonly TextContent: "TEXT_CONTENT";
    readonly Plan: "PLAN";
};
export type ChatCitationType = (typeof ChatCitationType)[keyof typeof ChatCitationType];
