import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatConnector: core.serialization.ObjectSchema<serializers.ChatConnector.Raw, Cohere.ChatConnector>;
export declare namespace ChatConnector {
    interface Raw {
        id: string;
        user_access_token?: string | null;
        continue_on_failure?: boolean | null;
        options?: Record<string, unknown> | null;
    }
}
