import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ToolCallV2Function: core.serialization.ObjectSchema<serializers.ToolCallV2Function.Raw, Cohere.ToolCallV2Function>;
export declare namespace ToolCallV2Function {
    interface Raw {
        name?: string | null;
        arguments?: string | null;
    }
}
