import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatToolCallStartEventDeltaMessage } from "./ChatToolCallStartEventDeltaMessage";
export declare const ChatToolCallStartEventDelta: core.serialization.ObjectSchema<serializers.ChatToolCallStartEventDelta.Raw, Cohere.ChatToolCallStartEventDelta>;
export declare namespace ChatToolCallStartEventDelta {
    interface Raw {
        message?: ChatToolCallStartEventDeltaMessage.Raw | null;
    }
}
