"use strict";
// This file was auto-generated by Fern from our API Definition.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.V2ChatStreamRequest = void 0;
const core = __importStar(require("../../../../../core"));
const ChatMessages_1 = require("../../../../types/ChatMessages");
const CitationOptions_1 = require("../../../../types/CitationOptions");
const ResponseFormatV2_1 = require("../../../../types/ResponseFormatV2");
const Thinking_1 = require("../../../../types/Thinking");
const ToolV2_1 = require("../../../../types/ToolV2");
const V2ChatStreamRequestDocumentsItem_1 = require("../../types/V2ChatStreamRequestDocumentsItem");
const V2ChatStreamRequestSafetyMode_1 = require("../../types/V2ChatStreamRequestSafetyMode");
const V2ChatStreamRequestToolChoice_1 = require("../../types/V2ChatStreamRequestToolChoice");
exports.V2ChatStreamRequest = core.serialization.object({
    model: core.serialization.string(),
    messages: ChatMessages_1.ChatMessages,
    tools: core.serialization.list(ToolV2_1.ToolV2).optional(),
    strictTools: core.serialization.property("strict_tools", core.serialization.boolean().optional()),
    documents: core.serialization.list(V2ChatStreamRequestDocumentsItem_1.V2ChatStreamRequestDocumentsItem).optional(),
    citationOptions: core.serialization.property("citation_options", CitationOptions_1.CitationOptions.optional()),
    responseFormat: core.serialization.property("response_format", ResponseFormatV2_1.ResponseFormatV2.optional()),
    safetyMode: core.serialization.property("safety_mode", V2ChatStreamRequestSafetyMode_1.V2ChatStreamRequestSafetyMode.optional()),
    maxTokens: core.serialization.property("max_tokens", core.serialization.number().optional()),
    stopSequences: core.serialization.property("stop_sequences", core.serialization.list(core.serialization.string()).optional()),
    temperature: core.serialization.number().optional(),
    seed: core.serialization.number().optional(),
    frequencyPenalty: core.serialization.property("frequency_penalty", core.serialization.number().optional()),
    presencePenalty: core.serialization.property("presence_penalty", core.serialization.number().optional()),
    k: core.serialization.number().optional(),
    p: core.serialization.number().optional(),
    logprobs: core.serialization.boolean().optional(),
    toolChoice: core.serialization.property("tool_choice", V2ChatStreamRequestToolChoice_1.V2ChatStreamRequestToolChoice.optional()),
    thinking: Thinking_1.Thinking.optional(),
    priority: core.serialization.number().optional(),
});
