import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { Dataset } from "../../../types/Dataset";
export declare const DatasetsListResponse: core.serialization.ObjectSchema<serializers.DatasetsListResponse.Raw, Cohere.DatasetsListResponse>;
export declare namespace DatasetsListResponse {
    interface Raw {
        datasets?: Dataset.Raw[] | null;
    }
}
