import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { AssistantMessageResponseContentItem } from "./AssistantMessageResponseContentItem";
import { Citation } from "./Citation";
import { ToolCallV2 } from "./ToolCallV2";
export declare const AssistantMessageResponse: core.serialization.ObjectSchema<serializers.AssistantMessageResponse.Raw, Cohere.AssistantMessageResponse>;
export declare namespace AssistantMessageResponse {
    interface Raw {
        role: "assistant";
        tool_calls?: ToolCallV2.Raw[] | null;
        tool_plan?: string | null;
        content?: AssistantMessageResponseContentItem.Raw[] | null;
        citations?: Citation.Raw[] | null;
    }
}
