import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const DatasetValidationStatus: core.serialization.Schema<serializers.DatasetValidationStatus.Raw, Cohere.DatasetValidationStatus>;
export declare namespace DatasetValidationStatus {
    type Raw = "unknown" | "queued" | "processing" | "failed" | "validated" | "skipped";
}
