"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatFinishReason = void 0;
/**
 * The reason a chat request has finished.
 *
 * - **complete**: The model finished sending a complete message.
 * - **max_tokens**: The number of generated tokens exceeded the model's context length or the value specified via the `max_tokens` parameter.
 * - **stop_sequence**: One of the provided `stop_sequence` entries was reached in the model's generation.
 * - **tool_call**: The model generated a Tool Call and is expecting a Tool Message in return
 * - **error**: The generation failed due to an internal error
 * - **timeout**: The generation was stopped because it exceeded the allowed time limit.
 */
exports.ChatFinishReason = {
    Complete: "COMPLETE",
    StopSequence: "STOP_SEQUENCE",
    MaxTokens: "MAX_TOKENS",
    ToolCall: "TOOL_CALL",
    Error: "ERROR",
    Timeout: "TIMEOUT",
};
