"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FinetuningUpdateFinetunedModelRequest = void 0;
var FinetuningUpdateFinetunedModelRequest_1 = require("./FinetuningUpdateFinetunedModelRequest");
Object.defineProperty(exports, "FinetuningUpdateFinetunedModelRequest", { enumerable: true, get: function () { return FinetuningUpdateFinetunedModelRequest_1.FinetuningUpdateFinetunedModelRequest; } });
