import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
import { GenerateStreamRequestReturnLikelihoods } from "../../types/GenerateStreamRequestReturnLikelihoods";
import { GenerateStreamRequestTruncate } from "../../types/GenerateStreamRequestTruncate";
export declare const GenerateStreamRequest: core.serialization.Schema<serializers.GenerateStreamRequest.Raw, Cohere.GenerateStreamRequest>;
export declare namespace GenerateStreamRequest {
    interface Raw {
        prompt: string;
        model?: string | null;
        num_generations?: number | null;
        max_tokens?: number | null;
        truncate?: GenerateStreamRequestTruncate.Raw | null;
        temperature?: number | null;
        seed?: number | null;
        preset?: string | null;
        end_sequences?: string[] | null;
        stop_sequences?: string[] | null;
        k?: number | null;
        p?: number | null;
        frequency_penalty?: number | null;
        presence_penalty?: number | null;
        return_likelihoods?: GenerateStreamRequestReturnLikelihoods.Raw | null;
        raw_prompting?: boolean | null;
    }
}
