import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatToolPlanDeltaEventDeltaMessage } from "./ChatToolPlanDeltaEventDeltaMessage";
export declare const ChatToolPlanDeltaEventDelta: core.serialization.ObjectSchema<serializers.ChatToolPlanDeltaEventDelta.Raw, Cohere.ChatToolPlanDeltaEventDelta>;
export declare namespace ChatToolPlanDeltaEventDelta {
    interface Raw {
        message?: ChatToolPlanDeltaEventDeltaMessage.Raw | null;
    }
}
