/**
 * @example
 *     {
 *         limit: 1.1,
 *         offset: 1.1
 *     }
 */
export interface ConnectorsListRequest {
    /** Maximum number of connectors to return [0, 100]. */
    limit?: number;
    /** Number of connectors to skip before returning results [0, inf]. */
    offset?: number;
}
