import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const TrainingStepMetrics: core.serialization.ObjectSchema<serializers.finetuning.TrainingStepMetrics.Raw, Cohere.finetuning.TrainingStepMetrics>;
export declare namespace TrainingStepMetrics {
    interface Raw {
        created_at?: string | null;
        step_number?: number | null;
        metrics?: Record<string, number> | null;
    }
}
