import type * as Cohere from "../../../../../api/index";
import * as core from "../../../../../core";
import type * as serializers from "../../../../index";
import { Settings } from "../../resources/finetuning/types/Settings";
import { Status } from "../../resources/finetuning/types/Status";
export declare const FinetuningUpdateFinetunedModelRequest: core.serialization.Schema<serializers.FinetuningUpdateFinetunedModelRequest.Raw, Cohere.FinetuningUpdateFinetunedModelRequest>;
export declare namespace FinetuningUpdateFinetunedModelRequest {
    interface Raw {
        name: string;
        settings: Settings.Raw;
        status?: Status.Raw | null;
    }
}
