import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ToolCall: core.serialization.ObjectSchema<serializers.ToolCall.Raw, Cohere.ToolCall>;
export declare namespace ToolCall {
    interface Raw {
        name: string;
        parameters: Record<string, unknown>;
    }
}
