import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ImageUrlDetail: core.serialization.Schema<serializers.ImageUrlDetail.Raw, Cohere.ImageUrlDetail>;
export declare namespace ImageUrlDetail {
    type Raw = "auto" | "low" | "high";
}
