import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const LogprobItem: core.serialization.ObjectSchema<serializers.LogprobItem.Raw, Cohere.LogprobItem>;
export declare namespace LogprobItem {
    interface Raw {
        text?: string | null;
        token_ids: number[];
        logprobs?: number[] | null;
    }
}
