import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ApiMetaTokens: core.serialization.ObjectSchema<serializers.ApiMetaTokens.Raw, Cohere.ApiMetaTokens>;
export declare namespace ApiMetaTokens {
    interface Raw {
        input_tokens?: number | null;
        output_tokens?: number | null;
    }
}
