import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ImageUrlDetail } from "./ImageUrlDetail";
export declare const ImageUrl: core.serialization.ObjectSchema<serializers.ImageUrl.Raw, Cohere.ImageUrl>;
export declare namespace ImageUrl {
    interface Raw {
        url: string;
        detail?: ImageUrlDetail.Raw | null;
    }
}
