import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const Document: core.serialization.ObjectSchema<serializers.Document.Raw, Cohere.Document>;
export declare namespace Document {
    interface Raw {
        data: Record<string, unknown>;
        id?: string | null;
    }
}
