import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
import { BaseType } from "./BaseType";
import { Strategy } from "./Strategy";
export declare const BaseModel: core.serialization.ObjectSchema<serializers.finetuning.BaseModel.Raw, Cohere.finetuning.BaseModel>;
export declare namespace BaseModel {
    interface Raw {
        name?: string | null;
        version?: string | null;
        base_type: BaseType.Raw;
        strategy?: Strategy.Raw | null;
    }
}
