/**
 * Used to control whether or not the model will be forced to use a tool when answering. When `REQUIRED` is specified, the model will be forced to use at least one of the user-defined tools, and the `tools` parameter must be passed in the request.
 * When `NONE` is specified, the model will be forced **not** to use one of the specified tools, and give a direct response.
 * If tool_choice isn't specified, then the model is free to choose whether to use the specified tools or not.
 *
 * **Note**: This parameter is only compatible with models [Command-r7b](https://docs.cohere.com/v2/docs/command-r7b) and newer.
 */
export declare const V2ChatStreamRequestToolChoice: {
    readonly Required: "REQUIRED";
    readonly None: "NONE";
};
export type V2ChatStreamRequestToolChoice = (typeof V2ChatStreamRequestToolChoice)[keyof typeof V2ChatStreamRequestToolChoice];
