import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatTextGenerationEvent: core.serialization.ObjectSchema<serializers.ChatTextGenerationEvent.Raw, Cohere.ChatTextGenerationEvent>;
export declare namespace ChatTextGenerationEvent {
    interface Raw extends ChatStreamEvent.Raw {
        text: string;
    }
}
