import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
export declare const DetokenizeRequest: core.serialization.Schema<serializers.DetokenizeRequest.Raw, Cohere.DetokenizeRequest>;
export declare namespace DetokenizeRequest {
    interface Raw {
        tokens: number[];
        model: string;
    }
}
