import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatSearchQuery } from "./ChatSearchQuery";
import { ChatSearchResultConnector } from "./ChatSearchResultConnector";
export declare const ChatSearchResult: core.serialization.ObjectSchema<serializers.ChatSearchResult.Raw, Cohere.ChatSearchResult>;
export declare namespace ChatSearchResult {
    interface Raw {
        search_query?: ChatSearchQuery.Raw | null;
        connector: ChatSearchResultConnector.Raw;
        document_ids: string[];
        error_message?: string | null;
        continue_on_failure?: boolean | null;
    }
}
