import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { EmbedImage } from "./EmbedImage";
import { EmbedText } from "./EmbedText";
export declare const EmbedContent: core.serialization.Schema<serializers.EmbedContent.Raw, Cohere.EmbedContent>;
export declare namespace EmbedContent {
    type Raw = EmbedContent.ImageUrl | EmbedContent.Text;
    interface ImageUrl extends EmbedImage.Raw {
        type: "image_url";
    }
    interface Text extends EmbedText.Raw {
        type: "text";
    }
}
