"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbedJobStatus = void 0;
/** The status of the embed job */
exports.EmbedJobStatus = {
    Processing: "processing",
    Complete: "complete",
    Cancelling: "cancelling",
    Cancelled: "cancelled",
    Failed: "failed",
};
