import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatMessageEndEventDelta } from "./ChatMessageEndEventDelta";
import { ChatStreamEventType } from "./ChatStreamEventType";
export declare const ChatMessageEndEvent: core.serialization.ObjectSchema<serializers.ChatMessageEndEvent.Raw, Cohere.ChatMessageEndEvent>;
export declare namespace ChatMessageEndEvent {
    interface Raw extends ChatStreamEventType.Raw {
        id?: string | null;
        delta?: ChatMessageEndEventDelta.Raw | null;
    }
}
