import type * as Cohere from "../../../index";
/**
 * Response to request to create a batch.
 */
export interface CreateBatchResponse {
    /** Information about the batch. */
    batch: Cohere.Batch;
}
