/** The validation status of the dataset */
export declare const DatasetValidationStatus: {
    readonly Unknown: "unknown";
    readonly Queued: "queued";
    readonly Processing: "processing";
    readonly Failed: "failed";
    readonly Validated: "validated";
    readonly Skipped: "skipped";
};
export type DatasetValidationStatus = (typeof DatasetValidationStatus)[keyof typeof DatasetValidationStatus];
