import type * as Cohere from "../index";
/**
 * Represents a single message in the chat history, excluding the current user turn. It has two properties: `role` and `message`. The `role` identifies the sender (`CHATBOT`, `SYSTEM`, or `USER`), while the `message` contains the text content.
 *
 * The chat_history parameter should not be used for `SYSTEM` messages in most cases. Instead, to add a `SYSTEM` role message at the beginning of a conversation, the `preamble` parameter should be used.
 */
export interface ChatMessage {
    /** Contents of the chat message. */
    message: string;
    toolCalls?: Cohere.ToolCall[];
}
