import type * as Cohere from "../index";
export interface EmbedByTypeResponse {
    id: string;
    /** An object with different embedding types. The length of each embedding type array will be the same as the length of the original `texts` array. */
    embeddings: Cohere.EmbedByTypeResponseEmbeddings;
    /** The text entries for which embeddings were returned. */
    texts?: string[];
    /** The image entries for which embeddings were returned. */
    images?: Cohere.Image[];
    meta?: Cohere.ApiMeta;
}
