"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClassifyResponseClassificationsItemClassificationType = void 0;
/** The type of classification performed */
exports.ClassifyResponseClassificationsItemClassificationType = {
    SingleLabel: "single-label",
    MultiLabel: "multi-label",
};
