"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateEmbedJobRequest = void 0;
var CreateEmbedJobRequest_1 = require("./CreateEmbedJobRequest");
Object.defineProperty(exports, "CreateEmbedJobRequest", { enumerable: true, get: function () { return CreateEmbedJobRequest_1.CreateEmbedJobRequest; } });
