import type * as Cohere from "../index";
/**
 * A message from the user.
 */
export interface UserMessageV2 {
    /**
     * The content of the message. This can be a string or a list of content blocks.
     * If a string is provided, it will be treated as a text content block.
     */
    content: Cohere.UserMessageV2Content;
}
