import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const RerankResponseResultsItemDocument: core.serialization.ObjectSchema<serializers.RerankResponseResultsItemDocument.Raw, Cohere.RerankResponseResultsItemDocument>;
export declare namespace RerankResponseResultsItemDocument {
    interface Raw {
        text: string;
    }
}
