/**
 * Defaults to `"enabled"`.
 * Citations are enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`.
 *
 * Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
 */
export declare const ChatStreamRequestCitationQuality: {
    readonly Enabled: "ENABLED";
    readonly Disabled: "DISABLED";
    readonly Fast: "FAST";
    readonly Accurate: "ACCURATE";
    readonly Off: "OFF";
};
export type ChatStreamRequestCitationQuality = (typeof ChatStreamRequestCitationQuality)[keyof typeof ChatStreamRequestCitationQuality];
