import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const Image: core.serialization.ObjectSchema<serializers.Image.Raw, Cohere.Image>;
export declare namespace Image {
    interface Raw {
        width: number;
        height: number;
        format: string;
        bit_depth: number;
    }
}
