import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatToolCallDeltaEventDeltaMessageToolCallsFunction: core.serialization.ObjectSchema<serializers.ChatToolCallDeltaEventDeltaMessageToolCallsFunction.Raw, Cohere.ChatToolCallDeltaEventDeltaMessageToolCallsFunction>;
export declare namespace ChatToolCallDeltaEventDeltaMessageToolCallsFunction {
    interface Raw {
        arguments?: string | null;
    }
}
