import type * as Cohere from "../index";
export interface SingleGenerationInStream {
    id: string;
    /** Full text of the generation. */
    text: string;
    /** Refers to the nth generation. Only present when `num_generations` is greater than zero. */
    index?: number;
    finishReason: Cohere.FinishReason;
}
