import type * as Cohere from "../index";
/**
 * Represents a single message in the chat history from a given role.
 */
export type ChatMessageV2 = Cohere.ChatMessageV2.User | Cohere.ChatMessageV2.Assistant | Cohere.ChatMessageV2.System | Cohere.ChatMessageV2.Tool;
export declare namespace ChatMessageV2 {
    interface User extends Cohere.UserMessageV2 {
        role: "user";
    }
    interface Assistant extends Cohere.AssistantMessage {
        role: "assistant";
    }
    interface System extends Cohere.SystemMessageV2 {
        role: "system";
    }
    interface Tool extends Cohere.ToolMessageV2 {
        role: "tool";
    }
}
