import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { RerankDocument } from "./RerankDocument";
export declare const RerankRequestDocumentsItem: core.serialization.Schema<serializers.RerankRequestDocumentsItem.Raw, Cohere.RerankRequestDocumentsItem>;
export declare namespace RerankRequestDocumentsItem {
    type Raw = string | RerankDocument.Raw;
}
