"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatRequestCitationQuality = void 0;
/**
 * Defaults to `"enabled"`.
 * Citations are enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`.
 *
 * Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
 */
exports.ChatRequestCitationQuality = {
    Enabled: "ENABLED",
    Disabled: "DISABLED",
    Fast: "FAST",
    Accurate: "ACCURATE",
    Off: "OFF",
};
