import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEvent } from "./ChatStreamEvent";
export declare const ChatStreamStartEvent: core.serialization.ObjectSchema<serializers.ChatStreamStartEvent.Raw, Cohere.ChatStreamStartEvent>;
export declare namespace ChatStreamStartEvent {
    interface Raw extends ChatStreamEvent.Raw {
        generation_id: string;
    }
}
