import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { CitationStartEventDeltaMessage } from "./CitationStartEventDeltaMessage";
export declare const CitationStartEventDelta: core.serialization.ObjectSchema<serializers.CitationStartEventDelta.Raw, Cohere.CitationStartEventDelta>;
export declare namespace CitationStartEventDelta {
    interface Raw {
        message?: CitationStartEventDeltaMessage.Raw | null;
    }
}
