import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolResult } from "./ToolResult";
export declare const ChatToolMessage: core.serialization.ObjectSchema<serializers.ChatToolMessage.Raw, Cohere.ChatToolMessage>;
export declare namespace ChatToolMessage {
    interface Raw {
        tool_results?: ToolResult.Raw[] | null;
    }
}
