export interface ChatDataMetrics {
    /** The sum of all turns of valid train examples. */
    numTrainTurns?: number;
    /** The sum of all turns of valid eval examples. */
    numEvalTurns?: number;
    /** The preamble of this dataset. */
    preamble?: string;
}
