import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbeddingType: core.serialization.Schema<serializers.EmbeddingType.Raw, Cohere.EmbeddingType>;
export declare namespace EmbeddingType {
    type Raw = "float" | "int8" | "uint8" | "binary" | "ubinary" | "base64";
}
