import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatDataMetrics: core.serialization.ObjectSchema<serializers.ChatDataMetrics.Raw, Cohere.ChatDataMetrics>;
export declare namespace ChatDataMetrics {
    interface Raw {
        num_train_turns?: number | null;
        num_eval_turns?: number | null;
        preamble?: string | null;
    }
}
