import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const JsonResponseFormat: core.serialization.ObjectSchema<serializers.JsonResponseFormat.Raw, Cohere.JsonResponseFormat>;
export declare namespace JsonResponseFormat {
    interface Raw {
        schema?: Record<string, unknown> | null;
    }
}
