import type * as Cohere from "../index";
/**
 * A Content block which contains information about the content type and the content itself.
 */
export type Content = Cohere.Content.Text | Cohere.Content.ImageUrl;
export declare namespace Content {
    interface Text extends Cohere.ChatTextContent {
        type: "text";
    }
    interface ImageUrl extends Cohere.ImageContent {
        type: "image_url";
    }
}
