import type * as Cohere from "../index";
export interface ChatSearchResult {
    searchQuery?: Cohere.ChatSearchQuery;
    /** The connector from which this result comes from. */
    connector: Cohere.ChatSearchResultConnector;
    /** Identifiers of documents found by this search query. */
    documentIds: string[];
    /** An error message if the search failed. */
    errorMessage?: string;
    /** Whether a chat request should continue or not if the request to this connector fails. */
    continueOnFailure?: boolean;
}
