import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const DatasetPart: core.serialization.ObjectSchema<serializers.DatasetPart.Raw, Cohere.DatasetPart>;
export declare namespace DatasetPart {
    interface Raw {
        id: string;
        name: string;
        url?: string | null;
        index?: number | null;
        size_bytes?: number | null;
        num_rows?: number | null;
        original_url?: string | null;
        samples?: string[] | null;
    }
}
