import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const CheckApiKeyResponse: core.serialization.ObjectSchema<serializers.CheckApiKeyResponse.Raw, Cohere.CheckApiKeyResponse>;
export declare namespace CheckApiKeyResponse {
    interface Raw {
        valid: boolean;
        organization_id?: string | null;
        owner_id?: string | null;
    }
}
