import type * as Cohere from "../index";
/**
 * Configuration for [reasoning features](https://docs.cohere.com/docs/reasoning).
 */
export interface Thinking {
    /** Reasoning is enabled by default for models that support it, but can be turned off by setting `"type": "disabled"`. */
    type: Cohere.ThinkingType;
    /**
     * The maximum number of tokens the model can use for thinking, which must be set to a positive integer.
     * The model will stop thinking if it reaches the thinking token budget and will proceed with the response.
     */
    tokenBudget?: number;
}
