import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatDocumentSource } from "./ChatDocumentSource";
import { ChatToolSource } from "./ChatToolSource";
export declare const Source: core.serialization.Schema<serializers.Source.Raw, Cohere.Source>;
export declare namespace Source {
    type Raw = Source.Tool | Source.Document;
    interface Tool extends ChatToolSource.Raw {
        type: "tool";
    }
    interface Document extends ChatDocumentSource.Raw {
        type: "document";
    }
}
