import type * as Cohere from "../index";
export type SystemMessageV2ContentItem = Cohere.SystemMessageV2ContentItem.Text;
export declare namespace SystemMessageV2ContentItem {
    interface Text extends Cohere.ChatTextContent {
        type: "text";
    }
}
