import type * as Cohere from "../index";
export interface ChatStreamStartEvent extends Cohere.ChatStreamEvent {
    /** Unique identifier for the generated reply. Useful for submitting feedback. */
    generationId: string;
}
