"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.BatchStatus = void 0;
/**
 * The possible stages of a batch life-cycle.
 *
 *  - BATCH_STATUS_UNSPECIFIED: Unspecified status.
 *  - BATCH_STATUS_QUEUED: The batch has been queued.
 *  - BATCH_STATUS_IN_PROGRESS: The batch is in-progress.
 *  - BATCH_STATUS_CANCELING: The batch is being canceled.
 *  - BATCH_STATUS_COMPLETED: The batch has been completed.
 *  - BATCH_STATUS_FAILED: The batch has failed.
 *  - BATCH_STATUS_CANCELED: The batch has been canceled.
 */
exports.BatchStatus = {
    BatchStatusUnspecified: "BATCH_STATUS_UNSPECIFIED",
    BatchStatusQueued: "BATCH_STATUS_QUEUED",
    BatchStatusInProgress: "BATCH_STATUS_IN_PROGRESS",
    BatchStatusCanceling: "BATCH_STATUS_CANCELING",
    BatchStatusCompleted: "BATCH_STATUS_COMPLETED",
    BatchStatusFailed: "BATCH_STATUS_FAILED",
    BatchStatusCanceled: "BATCH_STATUS_CANCELED",
};
