/** The type of citation which indicates what part of the response the citation is for. */
export declare const CitationType: {
    readonly TextContent: "TEXT_CONTENT";
    readonly ThinkingContent: "THINKING_CONTENT";
    readonly Plan: "PLAN";
};
export type CitationType = (typeof CitationType)[keyof typeof CitationType];
