import type * as Cohere from "../index";
/**
 * A section of the generated reply which cites external knowledge.
 */
export interface ChatCitation {
    /** The index of text that the citation starts at, counting from zero. For example, a generation of `Hello, world!` with a citation on `world` would have a start value of `7`. This is because the citation starts at `w`, which is the seventh character. */
    start: number;
    /** The index of text that the citation ends after, counting from zero. For example, a generation of `Hello, world!` with a citation on `world` would have an end value of `11`. This is because the citation ends after `d`, which is the eleventh character. */
    end: number;
    /** The text of the citation. For example, a generation of `Hello, world!` with a citation of `world` would have a text value of `world`. */
    text: string;
    /** Identifiers of documents cited by this section of the generated reply. */
    documentIds: string[];
    /** The type of citation which indicates what part of the response the citation is for. */
    type?: Cohere.ChatCitationType;
}
