import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
export declare const V2RerankResponseResultsItem: core.serialization.ObjectSchema<serializers.V2RerankResponseResultsItem.Raw, Cohere.V2RerankResponseResultsItem>;
export declare namespace V2RerankResponseResultsItem {
    interface Raw {
        index: number;
        relevance_score: number;
    }
}
