import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatSearchResultConnector: core.serialization.ObjectSchema<serializers.ChatSearchResultConnector.Raw, Cohere.ChatSearchResultConnector>;
export declare namespace ChatSearchResultConnector {
    interface Raw {
        id: string;
    }
}
