import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ToolV2Function: core.serialization.ObjectSchema<serializers.ToolV2Function.Raw, Cohere.ToolV2Function>;
export declare namespace ToolV2Function {
    interface Raw {
        name: string;
        description?: string | null;
        parameters: Record<string, unknown>;
    }
}
