"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbeddingType = void 0;
exports.EmbeddingType = {
    Float: "float",
    Int8: "int8",
    Uint8: "uint8",
    Binary: "binary",
    Ubinary: "ubinary",
    Base64: "base64",
};
