import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolParameterDefinitionsValue } from "./ToolParameterDefinitionsValue";
export declare const Tool: core.serialization.ObjectSchema<serializers.Tool.Raw, Cohere.Tool>;
export declare namespace Tool {
    interface Raw {
        name: string;
        description: string;
        parameter_definitions?: Record<string, ToolParameterDefinitionsValue.Raw> | null;
    }
}
