import type * as Cohere from "../index";
/**
 * A streamed delta event which contains a delta of chat text content.
 */
export interface ChatContentDeltaEvent extends Cohere.ChatStreamEventType {
    index?: number;
    delta?: Cohere.ChatContentDeltaEventDelta;
    logprobs?: Cohere.LogprobItem;
}
