import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ToolCall } from "./ToolCall";
export declare const ChatMessage: core.serialization.ObjectSchema<serializers.ChatMessage.Raw, Cohere.ChatMessage>;
export declare namespace ChatMessage {
    interface Raw {
        message: string;
        tool_calls?: ToolCall.Raw[] | null;
    }
}
