import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ApiMetaApiVersion: core.serialization.ObjectSchema<serializers.ApiMetaApiVersion.Raw, Cohere.ApiMetaApiVersion>;
export declare namespace ApiMetaApiVersion {
    interface Raw {
        version: string;
        is_deprecated?: boolean | null;
        is_experimental?: boolean | null;
    }
}
