import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEventType } from "./ChatStreamEventType";
import { ChatToolCallDeltaEventDelta } from "./ChatToolCallDeltaEventDelta";
export declare const ChatToolCallDeltaEvent: core.serialization.ObjectSchema<serializers.ChatToolCallDeltaEvent.Raw, Cohere.ChatToolCallDeltaEvent>;
export declare namespace ChatToolCallDeltaEvent {
    interface Raw extends ChatStreamEventType.Raw {
        index?: number | null;
        delta?: ChatToolCallDeltaEventDelta.Raw | null;
    }
}
