export interface DatasetPart {
    /** The dataset part ID */
    id: string;
    /** The name of the dataset part */
    name: string;
    /** The download url of the file */
    url?: string;
    /** The index of the file */
    index?: number;
    /** The size of the file in bytes */
    sizeBytes?: number;
    /** The number of rows in the file */
    numRows?: number;
    /** The download url of the original file */
    originalUrl?: string;
    /** The first few rows of the parsed file */
    samples?: string[];
}
