"use strict";
// This file was auto-generated by Fern from our API Definition.
Object.defineProperty(exports, "__esModule", { value: true });
exports.SummarizeRequestLength = void 0;
/** One of `short`, `medium`, `long`, or `auto` defaults to `auto`. Indicates the approximate length of the summary. If `auto` is selected, the best option will be picked based on the input text. */
exports.SummarizeRequestLength = {
    Short: "short",
    Medium: "medium",
    Long: "long",
};
