import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { Batch } from "./Batch";
export declare const CreateBatchResponse: core.serialization.ObjectSchema<serializers.CreateBatchResponse.Raw, Cohere.CreateBatchResponse>;
export declare namespace CreateBatchResponse {
    interface Raw {
        batch: Batch.Raw;
    }
}
