import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
import { EmbeddingType } from "../../types/EmbeddingType";
import { EmbedInputType } from "../../types/EmbedInputType";
import { EmbedRequestTruncate } from "../../types/EmbedRequestTruncate";
export declare const EmbedRequest: core.serialization.Schema<serializers.EmbedRequest.Raw, Cohere.EmbedRequest>;
export declare namespace EmbedRequest {
    interface Raw {
        texts?: string[] | null;
        images?: string[] | null;
        model?: string | null;
        input_type?: EmbedInputType.Raw | null;
        embedding_types?: EmbeddingType.Raw[] | null;
        truncate?: EmbedRequestTruncate.Raw | null;
    }
}
