import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedImageUrl: core.serialization.ObjectSchema<serializers.EmbedImageUrl.Raw, Cohere.EmbedImageUrl>;
export declare namespace EmbedImageUrl {
    interface Raw {
        url: string;
    }
}
