import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentStartEventDeltaMessage } from "./ChatContentStartEventDeltaMessage";
export declare const ChatContentStartEventDelta: core.serialization.ObjectSchema<serializers.ChatContentStartEventDelta.Raw, Cohere.ChatContentStartEventDelta>;
export declare namespace ChatContentStartEventDelta {
    interface Raw {
        message?: ChatContentStartEventDeltaMessage.Raw | null;
    }
}
