import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { EmbedContent } from "./EmbedContent";
export declare const EmbedInput: core.serialization.ObjectSchema<serializers.EmbedInput.Raw, Cohere.EmbedInput>;
export declare namespace EmbedInput {
    interface Raw {
        content: EmbedContent.Raw[];
    }
}
