import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { AssistantMessageResponse } from "../../../types/AssistantMessageResponse";
import { ChatFinishReason } from "../../../types/ChatFinishReason";
import { LogprobItem } from "../../../types/LogprobItem";
import { Usage } from "../../../types/Usage";
export declare const V2ChatResponse: core.serialization.ObjectSchema<serializers.V2ChatResponse.Raw, Cohere.V2ChatResponse>;
export declare namespace V2ChatResponse {
    interface Raw {
        id: string;
        finish_reason: ChatFinishReason.Raw;
        message: AssistantMessageResponse.Raw;
        usage?: Usage.Raw | null;
        logprobs?: LogprobItem.Raw[] | null;
    }
}
