export interface Image {
    /** Width of the image in pixels */
    width: number;
    /** Height of the image in pixels */
    height: number;
    /** Format of the image */
    format: string;
    /** Bit depth of the image */
    bitDepth: number;
}
