import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatStreamEndEventFinishReason } from "./ChatStreamEndEventFinishReason";
import { ChatStreamEvent } from "./ChatStreamEvent";
import { NonStreamedChatResponse } from "./NonStreamedChatResponse";
export declare const ChatStreamEndEvent: core.serialization.ObjectSchema<serializers.ChatStreamEndEvent.Raw, Cohere.ChatStreamEndEvent>;
export declare namespace ChatStreamEndEvent {
    interface Raw extends ChatStreamEvent.Raw {
        finish_reason: ChatStreamEndEventFinishReason.Raw;
        response: NonStreamedChatResponse.Raw;
    }
}
