import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const ChatMessageStartEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatMessageStartEventDeltaMessage.Raw, Cohere.ChatMessageStartEventDeltaMessage>;
export declare namespace ChatMessageStartEventDeltaMessage {
    interface Raw {
        role?: "assistant" | null;
    }
}
