import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatContentStartEventDeltaMessageContent } from "./ChatContentStartEventDeltaMessageContent";
export declare const ChatContentStartEventDeltaMessage: core.serialization.ObjectSchema<serializers.ChatContentStartEventDeltaMessage.Raw, Cohere.ChatContentStartEventDeltaMessage>;
export declare namespace ChatContentStartEventDeltaMessage {
    interface Raw {
        content?: ChatContentStartEventDeltaMessageContent.Raw | null;
    }
}
