import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const FinetuneDatasetMetrics: core.serialization.ObjectSchema<serializers.FinetuneDatasetMetrics.Raw, Cohere.FinetuneDatasetMetrics>;
export declare namespace FinetuneDatasetMetrics {
    interface Raw {
        trainable_token_count?: number | null;
        total_examples?: number | null;
        train_examples?: number | null;
        train_size_bytes?: number | null;
        eval_examples?: number | null;
        eval_size_bytes?: number | null;
    }
}
