import type * as Cohere from "../../../api/index";
import * as core from "../../../core";
import type * as serializers from "../../index";
import { SummarizeRequestExtractiveness } from "../../types/SummarizeRequestExtractiveness";
import { SummarizeRequestFormat } from "../../types/SummarizeRequestFormat";
import { SummarizeRequestLength } from "../../types/SummarizeRequestLength";
export declare const SummarizeRequest: core.serialization.Schema<serializers.SummarizeRequest.Raw, Cohere.SummarizeRequest>;
export declare namespace SummarizeRequest {
    interface Raw {
        text: string;
        length?: SummarizeRequestLength.Raw | null;
        format?: SummarizeRequestFormat.Raw | null;
        model?: string | null;
        extractiveness?: SummarizeRequestExtractiveness.Raw | null;
        temperature?: number | null;
        additional_command?: string | null;
    }
}
