import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
import { ChatMessageV2 } from "./ChatMessageV2";
export declare const ChatMessages: core.serialization.Schema<serializers.ChatMessages.Raw, Cohere.ChatMessages>;
export declare namespace ChatMessages {
    type Raw = ChatMessageV2.Raw[];
}
