/**
 * Relevant information that could be used by the model to generate a more accurate reply.
 * The content of each document are generally short (should be under 300 words). Metadata should be used to provide additional information, both the key name and the value will be
 * passed to the model.
 */
export interface Document {
    /** A relevant document that the model can cite to generate a more accurate reply. Each document is a string-any dictionary. */
    data: Record<string, unknown>;
    /** Unique identifier for this document which will be referenced in citations. If not provided an ID will be automatically generated. */
    id?: string;
}
