import type * as Cohere from "../../../../../../api/index";
import * as core from "../../../../../../core";
import type * as serializers from "../../../../../index";
export declare const DeleteFinetunedModelResponse: core.serialization.Schema<serializers.finetuning.DeleteFinetunedModelResponse.Raw, Cohere.finetuning.DeleteFinetunedModelResponse>;
export declare namespace DeleteFinetunedModelResponse {
    type Raw = Record<string, unknown>;
}
