import type * as Cohere from "../index";
export type AssistantMessageV2ContentItem = Cohere.AssistantMessageV2ContentItem.Text | Cohere.AssistantMessageV2ContentItem.Thinking;
export declare namespace AssistantMessageV2ContentItem {
    interface Text extends Cohere.ChatTextContent {
        type: "text";
    }
    interface Thinking extends Cohere.ChatThinkingContent {
        type: "thinking";
    }
}
