import type * as Cohere from "../../../../api/index";
import * as core from "../../../../core";
import type * as serializers from "../../../index";
import { BatchStatus } from "./BatchStatus";
export declare const Batch: core.serialization.ObjectSchema<serializers.Batch.Raw, Cohere.Batch>;
export declare namespace Batch {
    interface Raw {
        id?: string | null;
        name: string;
        creator_id?: string | null;
        org_id?: string | null;
        status?: BatchStatus.Raw | null;
        created_at?: string | null;
        updated_at?: string | null;
        input_dataset_id: string;
        output_dataset_id?: string | null;
        input_tokens?: string | null;
        output_tokens?: string | null;
        model: string;
        num_records?: number | null;
        num_successful_records?: number | null;
        num_failed_records?: number | null;
        status_reason?: string | null;
    }
}
