import type * as Cohere from "../../api/index";
import * as core from "../../core";
import type * as serializers from "../index";
export declare const EmbedText: core.serialization.ObjectSchema<serializers.EmbedText.Raw, Cohere.EmbedText>;
export declare namespace EmbedText {
    interface Raw {
        text?: string | null;
    }
}
