import type * as Cohere from "../index";
/**
 * A streamed event which signifies that a stream has started.
 */
export interface ChatMessageStartEvent extends Cohere.ChatStreamEventType {
    /** Unique identifier for the generated reply. */
    id?: string;
    delta?: Cohere.ChatMessageStartEventDelta;
}
