import type * as Cohere from "../index";
export interface ChatContentStartEventDeltaMessageContent {
    thinking?: string;
    text?: string;
    type?: Cohere.ChatContentStartEventDeltaMessageContentType;
}
