export declare const ChatContentStartEventDeltaMessageContentType: {
    readonly Text: "text";
    readonly Thinking: "thinking";
};
export type ChatContentStartEventDeltaMessageContentType = (typeof ChatContentStartEventDeltaMessageContentType)[keyof typeof ChatContentStartEventDeltaMessageContentType];
