import type * as Cohere from "../index";
export type Message = Cohere.Message.Chatbot | Cohere.Message.System | Cohere.Message.User | Cohere.Message.Tool;
export declare namespace Message {
    interface Chatbot extends Cohere.ChatMessage {
        role: "CHATBOT";
    }
    interface System extends Cohere.ChatMessage {
        role: "SYSTEM";
    }
    interface User extends Cohere.ChatMessage {
        role: "USER";
    }
    interface Tool extends Cohere.ChatToolMessage {
        role: "TOOL";
    }
}
